@@ -4,7 +4,7 @@ static char rcsid[] = "$Id: colorconf.c 934 2008-02-23 00:44:29Z hubert@u.washin
 
 /*
  * ========================================================================
- * Copyright 2013-2017 Eduardo Chappa
+ * Copyright 2013-2020 Eduardo Chappa
  * Copyright 2006-2008 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -1214,7 +1214,8 @@ offer_none_color_for_var(struct pine *ps, struct variable *var)
 	       || var == &ps->vars[V_KW_COLORS]));
 }
 
-char *colorindexrule(char *s)
+char *
+colorindexrule(char *s)
 {
    char *conftext;
    char ***alval, **t;
