@@ -2,7 +2,7 @@
  * $Id: keymenu.h 1074 2008-06-04 00:08:43Z hubert@u.washington.edu $
  *
  * ========================================================================
- * Copyright 2013-2017 Eduardo Chappa
+ * Copyright 2013-2020 Eduardo Chappa
  * Copyright 2006-2008 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -215,6 +215,7 @@ struct key_menu {
 #define	MC_DECRYPT	802
 #define MC_QUOTA	803
 #define MC_ADDHEADER	804
+#define MC_XOAUTH2	805
 
 
 /* Commands for S/MIME screens */
@@ -241,7 +242,7 @@ struct key_menu {
  * label (the Save part) but the actual command (the S) will stay
  * the same, so it will be very difficult to come up with mnemonic
  * labels. The mnemonic isn't necessary, just nice. You can see that
- * we have stretched to the edge of the usefullness of mnemonics with
+ * we have stretched to the edge of the usefulness of mnemonics with
  * cases like K Kolor (instead of Color) and X eXceptions (because E
  * already meant something else).
  */
@@ -582,6 +583,7 @@ extern struct key_menu	cancel_keymenu,
 			rev_msg_keymenu,
 			ans_certfail_keymenu,
 			ans_certquery_keymenu,
+			oauth2_auth_keymenu,
 			forge_keymenu,
 			listmgr_keymenu,
 			index_keymenu,
@@ -666,12 +668,13 @@ extern struct key_menu	cancel_keymenu,
 			config_smime_manage_password_file_menu_keymenu,
 			smime_certificate_info_keymenu,
 			config_smime_add_new_key_keymenu,
-			config_smime_manage_view_cert_keymenu;
+			config_smime_manage_view_cert_keymenu,
+			config_smime_manage_view_cert_keymenu_no_delete;
 
 extern struct key rev_msg_keys[];
 
 
-/* exported protoypes */
+/* exported prototypes */
 void	    draw_cancel_keymenu(void);
 void	    end_keymenu(void);
 int	    menu_command(UCS, struct key_menu *);
