@@ -1,3 +1,9 @@
+/*
+ * Copyright 2016-2020 Eduardo Chappa
+ *
+ * Last Edited: July 21, 2018 Eduardo Chappa <chappa@washington.edu>
+ *
+ */
 /* ========================================================================
  * Copyright 2008-2011 Mark Crispin
  * ========================================================================
@@ -142,7 +148,17 @@
 #define SET_RFC822OUTPUTFULL (long) 160
 #define GET_BLOCKENVINIT (long) 161
 #define SET_BLOCKENVINIT (long) 162
-
+#define GET_UCS4WIDTH (long) 163
+#define SET_UCS4WIDTH (long) 164
+#define GET_IDPARAMS  (long) 165
+#define SET_IDPARAMS  (long) 166
+#define GET_IDSTREAM  (long) 167
+#define SET_IDSTREAM  (long) 168
+#define GET_OA2CLIENTGETACCESSCODE (long) 169
+#define SET_OA2CLIENTGETACCESSCODE (long) 170
+#define GET_OA2CLIENTINFO (long) 171
+#define SET_OA2CLIENTINFO (long) 172
+
 	/* 2xx: environment */
 #define GET_USERNAME (long) 201
 #define SET_USERNAME (long) 202
@@ -218,6 +234,10 @@
 #define SET_SSLCLIENTKEY (long) 335
 #define GET_KERBEROS_CP_SVR_NAME (long) 336
 #define SET_KERBEROS_CP_SVR_NAME (long) 337
+#define GET_ENCRYPTION_RANGE_MIN (long) 338
+#define SET_ENCRYPTION_RANGE_MIN (long) 339
+#define GET_ENCRYPTION_RANGE_MAX (long) 340
+#define SET_ENCRYPTION_RANGE_MAX (long) 341
 
 	/* 4xx: network drivers */
 #define GET_MAXLOGINTRIALS (long) 400
@@ -380,7 +400,7 @@
 #define DR_HALFOPEN (long) 0x10000
 #define DR_DIRFMT (long) 0x20000/* driver is a directory-format */
 #define DR_MODSEQ (long) 0x40000/* driver supports modseqs */
-
+#define DR_SHORTLIVED (long) 0x80000/* assume server disconnects after sending command  */
 
 /* Cache management function codes */
 
@@ -430,13 +450,13 @@
 				/* try SSL mode */
 #define NET_TRYSSL ((unsigned long) 0x8000000)
 				/* try TLS1 mode */
-#define NET_TRYTLS1   ((unsigned long) 0x1000000)
+#define NET_TRYTLS1   ((unsigned long) 0x4000000)
 				/* try TLS1_1 mode */
 #define NET_TRYTLS1_1 ((unsigned long) 0x2000000)
 				/* try TLS1_2 mode */
-#define NET_TRYTLS1_2 ((unsigned long) 0x4000000)
-				/* try DTLS1 mode */
-#define NET_TRYDTLS1   ((unsigned long) 0x8000000)
+#define NET_TRYTLS1_2 ((unsigned long) 0x1000000)
+				/* try TLS1_3 mode */
+#define NET_TRYTLS1_3 ((unsigned long) 0x800000)
 
 /* Close options */
 
@@ -579,7 +599,20 @@
 #define LATT_HASCHILDREN (long) 0x20
 				/* has no selectable inferiors */
 #define LATT_HASNOCHILDREN (long) 0x40
-
+				/* folder contains all messages */
+#define LATT_ALL (long) 0x80
+				/* folder contains archived messages */
+#define LATT_ARCHIVE (long) 0x100
+				/* folder contains drafts */
+#define LATT_DRAFTS (long) 0x200
+				/* folder contains Flagged messages */
+#define LATT_FLAGGED (long) 0x400
+				/* folder contains junk messages */
+#define LATT_JUNK (long) 0x800
+				/* folder contains Sent mail */
+#define LATT_SENT (long) 0x1000
+				/* folder contains deleted messages */
+#define LATT_TRASH (long) 0x2000
 
 /* Sort functions */
 
@@ -651,10 +684,12 @@ STRINGLIST {
 #define NETMAXUSER 65
 #define NETMAXMBX (MAILTMPLEN/4)
 #define NETMAXSRV 21
+#define NETMAXAUTH 16
 typedef struct net_mailbox {
   char host[NETMAXHOST];	/* host name (may be canonicalized) */
   char orighost[NETMAXHOST];	/* host name before canonicalization */
   char user[NETMAXUSER];	/* user name */
+  char auth[NETMAXAUTH];	/* authenticator name (PLAIN, etc.) */
   char authuser[NETMAXUSER];	/* authentication user name */
   char mailbox[NETMAXMBX];	/* mailbox name */
   char service[NETMAXSRV];	/* service name */
@@ -666,7 +701,7 @@ typedef struct net_mailbox {
   unsigned int tls1    : 1;	/* Use TLSv1 */
   unsigned int tls1_1  : 1;	/* Use TLSv1.1 */
   unsigned int tls1_2  : 1;	/* Use TLSV1.2 */
-  unsigned int dtls1   : 1;	/* Use DTLSv1 */
+  unsigned int tls1_3  : 1;	/* Use TLSV1.3 */
   unsigned int trysslflag : 1;	/* try SSL driver first flag */
   unsigned int novalidate : 1;	/* don't validate certificates */
   unsigned int tlsflag : 1;	/* TLS flag */
@@ -681,7 +716,7 @@ typedef struct net_mailbox {
 			: (M).tls1	? NET_TRYTLS1	\
 			: (M).tls1_1	? NET_TRYTLS1_1	\
 			: (M).tls1_2	? NET_TRYTLS1_2	\
-			: (M).dtls1	? NET_TRYDTLS1	\
+			: (M).tls1_3	? NET_TRYTLS1_3	\
 			: NET_TLSCLIENT)
 
 
@@ -738,7 +773,8 @@ typedef struct mail_envelope {
 #define TYPEIMAGE 5		/* static image */
 #define TYPEVIDEO 6		/* video */
 #define TYPEMODEL 7		/* model */
-#define TYPEOTHER 8		/* unknown */
+#define TYPEALL 8		/* type "*" */
+#define TYPEOTHER 9		/* unknown */
 #define TYPEMAX 15		/* maximum type code */
 
 
@@ -971,6 +1007,7 @@ SEARCHPGM {			/* search program */
   STRINGLIST *subject;		/* text in subject */
   STRINGLIST *text;		/* text in headers and body */
   STRINGLIST *to;		/* to recipients */
+  STRINGLIST *x_gm_ext1;	/* use X-GM-EXT-1 extension */
   unsigned long larger;		/* larger than this size */
   unsigned long smaller;	/* smaller than this size */
   unsigned long older;		/* older than this interval */
@@ -1080,7 +1117,17 @@ QUOTALIST {
   unsigned long limit;		/* resource limit */
   QUOTALIST *next;		/* next resource */
 };
-
+
+/* ID List */
+
+#define IDLIST struct id_list
+
+IDLIST {
+  char *name;			/* name of field */
+  char *value;			/* value of the field */
+  IDLIST *next;			/* next value in the list */
+};
+
 /* Mail Access I/O stream */
 
 
@@ -1211,6 +1258,7 @@ NETDRIVER {
   char *(*remotehost) (void *stream);
   unsigned long (*port) (void *stream);
   char *(*localhost) (void *stream);
+  char *(*getsize) (void *stream, unsigned long size);
 };
 
 
@@ -1325,6 +1373,7 @@ typedef void *(*mailcache_t) (MAILSTREAM *stream,unsigned long msgno,long op);
 typedef long (*mailproxycopy_t) (MAILSTREAM *stream,char *sequence,
 				 char *mailbox,long options);
 typedef long (*tcptimeout_t) (long overall,long last, char *host);
+typedef long (*ucs4width_t) (unsigned long c);
 typedef void *(*authchallenge_t) (void *stream,unsigned long *len);
 typedef long (*authrespond_t) (void *stream,char *s,unsigned long size);
 typedef long (*authcheck_t) (void);
@@ -1619,7 +1668,8 @@ void mm_lsub (MAILSTREAM *stream,int delimiter,char *name,long attributes);
 void mm_status (MAILSTREAM *stream,char *mailbox,MAILSTATUS *status);
 void mm_log (char *string,long errflg);
 void mm_dlog (char *string);
-void mm_login (NETMBX *mb,char *user,char *pwd,long trial);
+void mm_login (NETMBX *mb,char *user,char **pwd,long trial);
+void mm_login_method (NETMBX *mb,char *user, void *info,long trial, char *method);
 void mm_critical (MAILSTREAM *stream);
 void mm_nocritical (MAILSTREAM *stream);
 long mm_diskerror (MAILSTREAM *stream,long errcode,long serious);
@@ -1798,6 +1848,7 @@ SORTPGM *mail_newsortpgm (void);
 THREADNODE *mail_newthreadnode (SORTCACHE *sc);
 ACLLIST *mail_newacllist (void);
 QUOTALIST *mail_newquotalist (void);
+void mail_free_idlist (IDLIST **idlist);
 void mail_free_body (BODY **body);
 void mail_free_body_data (BODY *body);
 void mail_free_body_parameter (PARAMETER **parameter);
@@ -1838,6 +1889,7 @@ char *net_host (NETSTREAM *stream);
 char *net_remotehost (NETSTREAM *stream);
 unsigned long net_port (NETSTREAM *stream);
 char *net_localhost (NETSTREAM *stream);
+char *net_getsize(NETSTREAM *stream, unsigned long size);
 
 long sm_subscribe (char *mailbox);
 long sm_unsubscribe (char *mailbox);
@@ -1846,7 +1898,7 @@ char *sm_read (char *sbname,void **sdb);
 void ssl_onceonlyinit (void);
 char *ssl_start_tls (char *s);
 void ssl_server_init (char *server);
-
+void free_c_client_module_globals(void);
 
 /* Server I/O functions */
 
@@ -1858,3 +1910,46 @@ long INWAIT (long seconds);
 int PSOUT (char *s);
 int PSOUTR (SIZEDTEXT *s);
 int PFLUSH (void);
+
+/* XOAUTH Client-Side Support */
+
+#define OA2NAME	"XOAUTH2"
+
+#define OAUTH2_MAX_EQUIV        (2)
+#define OAUTH2_TOT_EQUIV        (OAUTH2_MAX_EQUIV + 2)
+#define OAUTH2_PARAM_NUMBER	(7)
+
+typedef enum {OA2_Id = 0, OA2_Secret, OA2_Code, OA2_RefreshToken,
+	      OA2_Scope, OA2_Redirect,   
+	      OA2_GrantTypeforAccessToken, OA2_GrantTypefromRefreshToken,
+	      OA2_Response, OA2_State, OA2_Prompt, OA2_End} OA2_type;
+
+typedef enum {OA2_GetAccessCode = 0,
+	      OA2_GetAccessTokenFromAccessCode,
+	      OA2_GetAccessTokenFromRefreshToken,
+	      OA2_GetEnd} OA2_function;
+
+typedef struct OA2_param_s {
+   char *name;                          
+   char *value;
+} OAUTH2_PARAM_S;
+   
+typedef struct OA2_serverparam_s {
+  char *name;         /* method name: GET or POST */
+  char *urlserver;
+  OA2_type params[OAUTH2_PARAM_NUMBER];
+} OAUTH2_SERVER_METHOD_S;
+
+typedef struct oauth2_s {
+   unsigned char *name;                          /* provider name */
+   char *host[OAUTH2_TOT_EQUIV];        /* servers for which this data applies  */
+   OAUTH2_PARAM_S param[OA2_End];	/* parameters name and values for this server */
+		/* servers, methods and parameters to retrieve access code and tokens */
+   OAUTH2_SERVER_METHOD_S server_mthd[OA2_GetEnd];
+   char *access_token;
+   unsigned long expiration;
+} OAUTH2_S;
+
+typedef char *(*oauth2getaccesscode_t) (char *url, OAUTH2_S *, int *);
+typedef void (*oauth2clientinfo_t)(char *name, char **id, char **secret);
+
