@@ -1,5 +1,6 @@
 /* ========================================================================
  * Copyright 2008-2011 Mark Crispin
+ * Copyright 2019 Eduardo Chappa
  * ========================================================================
  */
 
@@ -9,7 +10,7 @@
  * Author:	Mark Crispin
  *
  * Date:	10 February 1992
- * Last Edited:	8 April 2011
+ * Last Edited:	July 10, 2019.
  *
  * Previous versions of this file were:
  *
@@ -70,9 +71,9 @@ typedef struct nntp_local {
   unsigned int notlsflag : 1;	/* TLS not used in session */
   unsigned int sslflag : 1;	/* SSL session */
   unsigned int tls1 : 1;	/* TLSv1 on SSL port */
-  unsigned int dtls1 : 1;	/* DTLSv1 on SSL port */
   unsigned int tls1_1 : 1;	/* TLSv1_1 on SSL port */
   unsigned int tls1_2 : 1;	/* TLSv1_2 on SSL port */
+  unsigned int tls1_3 : 1;	/* TLSv1_3 on SSL port */
   unsigned int novalidate : 1;	/* certificate not validated */
   unsigned int xover : 1;	/* supports XOVER */
   unsigned int xhdr : 1;	/* supports XHDR */
@@ -584,7 +585,7 @@ long nntp_status (MAILSTREAM *stream,char *mbx,long flags)
     status.uidvalidity = stream->uid_validity;
 				/* pass status to main program */
     mm_status (stream,mbx,&status);
-    ret = T;			/* succes */
+    ret = T;			/* success */
   }
 				/* flush temporary stream */
   if (tstream) mail_close (tstream);
@@ -667,9 +668,9 @@ MAILSTREAM *nntp_mopen (MAILSTREAM *stream)
     if (LOCAL->notlsflag) mb.notlsflag = T;
     if (LOCAL->sslflag) mb.sslflag = T;
     if (LOCAL->tls1) mb.tls1 = T;
-    if (LOCAL->dtls1) mb.dtls1 = T;
     if (LOCAL->tls1_1) mb.tls1_1 = T;
     if (LOCAL->tls1_2) mb.tls1_2 = T;
+    if (LOCAL->tls1_3) mb.tls1_3 = T;
     if (LOCAL->novalidate) mb.novalidate = T;
     if (LOCAL->nntpstream->loser) mb.loser = T;
     if (stream->secure) mb.secflag = T;
@@ -694,7 +695,7 @@ MAILSTREAM *nntp_mopen (MAILSTREAM *stream)
     if (mb.tls1) strcat (tmp,"/tls1");
     if (mb.tls1_1) strcat (tmp,"/tls1_1");
     if (mb.tls1_2) strcat (tmp,"/tls1_2");
-    if (mb.dtls1) strcat (tmp,"/dtls1");
+    if (mb.tls1_3) strcat (tmp,"/tls1_3");
     if (mb.novalidate) strcat (tmp,"/novalidate-cert");
     if (mb.loser) strcat (tmp,"/loser");
     if (mb.secflag) strcat (tmp,"/secure");
@@ -765,9 +766,9 @@ MAILSTREAM *nntp_mopen (MAILSTREAM *stream)
   if (LOCAL->notlsflag) strcat (tmp,"/notls");
   if (LOCAL->sslflag) strcat (tmp,"/ssl");
   if (LOCAL->tls1) strcat (tmp,"/tls1");
-  if (LOCAL->dtls1) strcat (tmp,"/dtls1");
   if (LOCAL->tls1_1) strcat (tmp,"/tls1_1");
   if (LOCAL->tls1_2) strcat (tmp,"/tls1_2");
+  if (LOCAL->tls1_3) strcat (tmp,"/tls1_3");
   if (LOCAL->novalidate) strcat (tmp,"/novalidate-cert");
   if (LOCAL->nntpstream->loser) strcat (tmp,"/loser");
   if (stream->secure) strcat (tmp,"/secure");
@@ -1806,6 +1807,11 @@ SENDSTREAM *nntp_open_full (NETDRIVER *dv,char **hostlist,char *service,
     else if (extok) nntp_extensions (stream,(mb.secflag ? AU_SECURE : NIL) |
 				     (mb.authuser[0] ? AU_AUTHUSER : NIL));
   }
+  /* check one last time that we have a netstream before returning
+   * a stream that does not have it. Otherwise, nntp_mail will fail
+   * trying to dereference a null pointer.
+   */
+  if(stream && !stream->netstream) stream = nntp_close(stream);
   return stream;
 }
 
@@ -2039,7 +2045,7 @@ long nntp_send_auth (SENDSTREAM *stream,long flags)
 long nntp_send_auth_work (SENDSTREAM *stream,NETMBX *mb,char *pwd,long flags)
 {
   unsigned long trial,auths;
-  char tmp[MAILTMPLEN],usr[MAILTMPLEN];
+  char tmp[MAILTMPLEN],usr[MAILTMPLEN], *pwd2 = NIL;
   AUTHENTICATOR *at;
   char *lsterr = NIL;
   long ret = NIL;
@@ -2096,10 +2102,10 @@ long nntp_send_auth_work (SENDSTREAM *stream,NETMBX *mb,char *pwd,long flags)
   else for (trial = 0, pwd[0] = 'x';
 	    !ret && pwd[0] && (trial < nntp_maxlogintrials) &&
 	      stream->netstream; ) {
-    pwd[0] = NIL;		/* get user name and password */
-    mm_login (mb,usr,pwd,trial++);
+    mm_login (mb,usr, &pwd2,trial++);
+    pwd[0] = pwd2 ? pwd2[0] : '\0';
 				/* do the authentication */
-    if (pwd[0]) switch ((int) nntp_send_work (stream,"AUTHINFO USER",usr)) {
+    if (pwd2 && *pwd2) switch ((int) nntp_send_work (stream,"AUTHINFO USER",usr)) {
     case NNTPBADCMD:		/* give up if unrecognized command */
       mm_log (NNTP.ext.authuser ? stream->reply :
 	      "Can't do AUTHINFO USER to this server",ERROR);
@@ -2110,7 +2116,7 @@ long nntp_send_auth_work (SENDSTREAM *stream,NETMBX *mb,char *pwd,long flags)
       break;
     case NNTPWANTPASS:		/* wants password */
       stream->sensitive = T;	/* hide this command */
-      if (nntp_send_work (stream,"AUTHINFO PASS",pwd) == NNTPAUTHED)
+      if (nntp_send_work (stream,"AUTHINFO PASS",pwd2) == NNTPAUTHED)
 	ret = LONGT;		/* password OK */
       stream->sensitive = NIL;	/* unhide */
       if (ret) break;		/* OK if successful */
