@@ -424,7 +424,7 @@ MAILSTREAM *pop3_open (MAILSTREAM *stream)
       if (mb.tls1) strcat (tmp,"/tls1");
       if (mb.tls1_1) strcat (tmp,"/tls1_1");
       if (mb.tls1_2) strcat (tmp,"/tls1_2");
-      if (mb.dtls1) strcat (tmp,"/dtls1");
+      if (mb.tls1_3) strcat (tmp,"/tls1_3");
       if (mb.notlsflag) strcat (tmp,"/notls");
       if (mb.sslflag) strcat (tmp,"/ssl");
       if (mb.novalidate) strcat (tmp,"/novalidate-cert");
@@ -553,9 +553,9 @@ long pop3_capa (MAILSTREAM *stream,long flags)
 
 long pop3_auth (MAILSTREAM *stream,NETMBX *mb,char *pwd,char *usr)
 {
-  unsigned long i,trial,auths = 0;
-  char *t;
-  AUTHENTICATOR *at;
+  unsigned long i,trial,auths = 0, authsaved;
+  char *t, *app_pwd = NIL;
+  AUTHENTICATOR *at, *atsaved;
   long ret = NIL;
   long flags = (stream->secure ? AU_SECURE : NIL) |
     (mb->authuser[0] ? AU_AUTHUSER : NIL);
@@ -612,6 +612,15 @@ long pop3_auth (MAILSTREAM *stream,NETMBX *mb,char *pwd,char *usr)
     }
     for (t = NIL, LOCAL->saslcancel = NIL; !ret && LOCAL->netstream && auths &&
 	 (at = mail_lookup_auth (find_rightmost_bit (&auths)+1)); ) {
+        if(mb && *mb->auth){
+           if(!compare_cstring(at->name, mb->auth))
+              atsaved = at;
+           else{
+              authsaved = auths;
+              continue;
+           }
+        }   
+
       if (t) {			/* previous authenticator failed? */
 	sprintf (pwd,"Retrying using %.80s authentication after %.80s",
 		 at->name,t);
@@ -649,6 +658,12 @@ long pop3_auth (MAILSTREAM *stream,NETMBX *mb,char *pwd,char *usr)
       }
       fs_give ((void **) &t);
     }
+    if(mb && *mb->auth){
+      if(!authsaved) sprintf (pwd,"Client does not support AUTH=%.80s authenticator",mb->auth);
+      else if (!atsaved) sprintf (pwd,"POP server does not support AUTH=%.80s authenticator",mb->auth);
+      if (!authsaved || !atsaved) mm_log (pwd,ERROR);
+  }
+
   }
 
   else if (stream->secure)
@@ -660,7 +675,12 @@ long pop3_auth (MAILSTREAM *stream,NETMBX *mb,char *pwd,char *usr)
     trial = 0;			/* initial trial count */
     do {
       pwd[0] = 0;		/* prompt user for password */
-      mm_login (mb,usr,pwd,trial++);
+      if(app_pwd) fs_give((void **) &app_pwd);
+      mm_login (mb,usr, &app_pwd,trial++);
+      if(app_pwd){ 
+	strncpy(pwd, app_pwd, MAILTMPLEN);
+	pwd[MAILTMPLEN-1] = '\0';
+      }
       if (pwd[0]) {		/* send login sequence if have password */
 	if (pop3_send (stream,"USER",usr)) {
 	  LOCAL->sensitive = T;	/* hide this command */
@@ -678,6 +698,7 @@ long pop3_auth (MAILSTREAM *stream,NETMBX *mb,char *pwd,char *usr)
     } while (!ret && pwd[0] && (trial < pop3_maxlogintrials) &&
 	     LOCAL->netstream);
   }
+  if(app_pwd) fs_give((void **) &app_pwd);
   memset (pwd,0,MAILTMPLEN);	/* erase password */
 				/* get capabilities if logged in */
   if (ret && capaok) pop3_capa (stream,flags);
