@@ -1,5 +1,5 @@
 /* ========================================================================
- * Copyright 2015 Eduardo Chappa
+ * Copyright 2015-2018 Eduardo Chappa
  * Copyright 2008 Mark Crispin
  * ========================================================================
  */
@@ -11,7 +11,7 @@
  *
  * Date:	27 July 1988
  * Last Edited:	19 November 2008 (Crispin)
- * Last Edited: 16 January 2015 (Chappa)
+ * Last Edited: 8 December 2018 (Chappa)
  *
  * Previous versions of this file were
  *
@@ -281,14 +281,22 @@ SENDSTREAM *smtp_open_full (NETDRIVER *dv,char **hostlist,char *service,
 
 long smtp_auth (SENDSTREAM *stream,NETMBX *mb,char *tmp)
 {
-  unsigned long trial,auths;
+  unsigned long trial,auths, authsaved;
   char *lsterr = NIL;
   char usr[MAILTMPLEN];
-  AUTHENTICATOR *at;
+  AUTHENTICATOR *at, *atsaved;
   long ret = NIL;
   for (auths = ESMTP.auth, stream->saslcancel = NIL;
        !ret && stream->netstream && auths &&
        (at = mail_lookup_auth (find_rightmost_bit (&auths) + 1)); ) {
+    if(mb && *mb->auth){
+       if(!compare_cstring(at->name, mb->auth))
+          atsaved = at;
+       else{
+          authsaved = auths;
+          continue;
+       }
+    }
     if (lsterr) {		/* previous authenticator failed? */
       sprintf (tmp,"Retrying using %s authentication after %.80s",
 	       at->name,lsterr);
@@ -330,6 +338,11 @@ long smtp_auth (SENDSTREAM *stream,NETMBX *mb,char *tmp)
     }
     fs_give ((void **) &lsterr);
   }
+  if(mb && *mb->auth){
+      if(!authsaved) sprintf (tmp, "Client does not support AUTH=%.80s authenticator",mb->auth);
+      else if (!atsaved) sprintf (tmp,"SMTP server does not support AUTH=%.80s authenticator",mb->auth);
+      if (!authsaved || !atsaved) mm_log (tmp,ERROR);
+  }
   return ret;			/* authentication failed */
 }
 
@@ -417,8 +430,8 @@ SENDSTREAM *smtp_close (SENDSTREAM *stream)
 long smtp_mail (SENDSTREAM *stream,char *type,ENVELOPE *env,BODY *body)
 {
   RFC822BUFFER buf;
-  char tmp[SENDBUFLEN+1], smtpserver[SENDBUFLEN+1];
-  long error = NIL;
+  char tmp[SENDBUFLEN+1], smtpserver[SENDBUFLEN+1], *error_string;
+  long error = NIL, i;
   long retry = NIL;
   buf.f = smtp_soutr;		/* initialize buffer */
   buf.s = stream->netstream;
@@ -478,7 +491,7 @@ long smtp_mail (SENDSTREAM *stream,char *type,ENVELOPE *env,BODY *body)
       }
     }
 				/* send "MAIL FROM" command */
-    switch (smtp_send (stream,type,tmp)) {
+    switch (i = smtp_send (stream,type,tmp)) {
     case SMTPUNAVAIL:		/* mailbox unavailable? */
     case SMTPWANTAUTH:		/* wants authentication? */
     case SMTPWANTAUTH2:
@@ -486,7 +499,12 @@ long smtp_mail (SENDSTREAM *stream,char *type,ENVELOPE *env,BODY *body)
     case SMTPOK:		/* looks good */
       break;
     default:			/* other failure */
+      error_string = stream && stream->reply ? cpystr(stream->reply) : NIL;
       smtp_send (stream,"RSET",NIL);
+      if(error_string){		/* report it */
+	smtp_seterror(stream, i, error_string);
+	fs_give((void **) &error_string);
+      }
       return NIL;
     }
 				/* negotiate the recipients */
