@@ -1,4 +1,18 @@
 /* ========================================================================
+ * Copyright 2008-2011 Mark Crispin
+ * ========================================================================
+ */
+
+/*
+ * Program:	Dummy routines
+ *
+ * Author:	Mark Crispin
+ *
+ * Date:	9 May 1991
+ * Last Edited:	8 April 2011
+ *
+ * Previous versions of this file were:
+ *
  * Copyright 1988-2007 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -7,23 +21,6 @@
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
- * 
- * ========================================================================
- */
-
-/*
- * Program:	Dummy routines
- *
- * Author:	Mark Crispin
- *		Networks and Distributed Computing
- *		Computing & Communications
- *		University of Washington
- *		Administration Building, AG-44
- *		Seattle, WA  98195
- *		Internet: MRC@CAC.Washington.EDU
- *
- * Date:	9 May 1991
- * Last Edited:	1 June 2007
  */
 
 
@@ -159,7 +156,7 @@ void dummy_scan (MAILSTREAM *stream,char *ref,char *pat,char *contents)
   if (!pat || !*pat) {		/* empty pattern? */
     if (dummy_canonicalize (test,ref,"*")) {
 				/* tie off name at root */
-      if (s = strchr (test,'/')) *++s = '\0';
+      if ((s = strchr (test,'/')) != NULL) *++s = '\0';
       else test[0] = '\0';
       dummy_listed (stream,'/',test,LATT_NOSELECT,NIL);
     }
@@ -167,13 +164,13 @@ void dummy_scan (MAILSTREAM *stream,char *ref,char *pat,char *contents)
 				/* get canonical form of name */
   else if (dummy_canonicalize (test,ref,pat)) {
 				/* found any wildcards? */
-    if (s = strpbrk (test,"%*")) {
+    if ((s = strpbrk (test,"%*")) != NULL) {
 				/* yes, copy name up to that point */
       strncpy (file,test,i = s - test);
       file[i] = '\0';		/* tie off */
     }
     else strcpy (file,test);	/* use just that name then */
-    if (s = strrchr (file,'/')){/* find directory name */
+    if ((s = strrchr (file,'/')) != NULL){/* find directory name */
       *++s = '\0';		/* found, tie off at that point */
       s = file;
     }
@@ -216,10 +213,10 @@ void dummy_list (MAILSTREAM *stream,char *ref,char *pat)
 void dummy_lsub (MAILSTREAM *stream,char *ref,char *pat)
 {
   void *sdb = NIL;
-  char *s,*t,test[MAILTMPLEN],tmp[MAILTMPLEN];
+  char *s,*t,test[MAILTMPLEN],tmp[MAILTMPLEN],tmpx[MAILTMPLEN];
   int showuppers = pat[strlen (pat) - 1] == '%';
 				/* get canonical form of name */
-  if (dummy_canonicalize (test,ref,pat) && (s = sm_read (&sdb))) do
+  if (dummy_canonicalize (test,ref,pat) && (s = sm_read (tmpx,&sdb))) do
     if (*s != '{') {
       if (!compare_cstring (s,"INBOX") &&
 	  pmatch ("INBOX",ucase (strcpy (tmp,test))))
@@ -230,7 +227,8 @@ void dummy_lsub (MAILSTREAM *stream,char *ref,char *pat)
 	if (pmatch_full (s,test,'/')) mm_lsub (stream,'/',s,LATT_NOSELECT);
       }
     }
-  while (s = sm_read (&sdb));	/* until no more subscriptions */
+				/* until no more subscriptions */
+  while ((s = sm_read (tmpx,&sdb)) != NULL);
 }
 
 
@@ -279,7 +277,7 @@ void dummy_list_work (MAILSTREAM *stream,char *dir,char *pat,char *contents,
   size_t len = 0;
 				/* punt if bogus name */
   if (!mailboxdir (tmp,dir,NIL)) return;
-  if (dp = opendir (tmp)) {	/* do nothing if can't open directory */
+  if ((dp = opendir (tmp)) != NULL) {	/* do nothing if can't open directory */
 				/* see if a non-namespace directory format */
     for (drivers = (DRIVER *) mail_parameters (NIL,GET_DRIVERS,NIL), dt = NIL;
 	 dir && !dt && drivers; drivers = drivers->next)
@@ -291,7 +289,7 @@ void dummy_list_work (MAILSTREAM *stream,char *dir,char *pat,char *contents,
       dummy_listed (stream,'/',dir,dt ? NIL : LATT_NOSELECT,contents);
 
 				/* scan directory, ignore . and .. */
-    if (!dir || dir[(len = strlen (dir)) - 1] == '/') while (d = readdir (dp))
+    if (!dir || dir[(len = strlen (dir)) - 1] == '/') while ((d = readdir (dp)) != NULL)
       if ((!(dt && (*dt) (d->d_name))) &&
 	  ((d->d_name[0] != '.') ||
 	   (((long) mail_parameters (NIL,GET_HIDEDOTFILES,NIL)) ? NIL :
@@ -482,7 +480,7 @@ long dummy_create_path (MAILSTREAM *stream,char *path,long dirmode)
   int wantdir = t && !t[1];
   int mask = umask (0);
   if (wantdir) *t = '\0';	/* flush trailing delimiter for directory */
-  if (s = strrchr (path,'/')) {	/* found superior to this name? */
+  if ((s = strrchr (path,'/')) != NULL) {	/* found superior to this name? */
     c = *++s;			/* remember first character of inferior */
     *s = '\0';			/* tie off to get just superior */
 				/* name doesn't exist, create it */
@@ -800,7 +798,7 @@ long dummy_canonicalize (char *tmp,char *ref,char *pat)
     else return NIL;		/* unknown namespace */
   }
 				/* count wildcards */
-  for (i = 0, s = tmp; *s; *s++) if ((*s == '*') || (*s == '%')) ++i;
+  for (i = 0, s = tmp; *s; s++) if ((*s == '*') || (*s == '%')) ++i;
   if (i > MAXWILDCARDS) {	/* ridiculous wildcarding? */
     MM_LOG ("Excessive wildcards in LIST/LSUB",ERROR);
     return NIL;
