@@ -411,10 +411,10 @@ int news_select (struct direct *name)
 }
 
 
-/* News file name comparision
+/* News file name comparison
  * Accepts: first candidate directory entry
  *	    second candidate directory entry
- * Returns: negative if d1 < d2, 0 if d1 == d2, postive if d1 > d2
+ * Returns: negative if d1 < d2, 0 if d1 == d2, positive if d1 > d2
  */
 
 int news_numsort (const void *d1,const void *d2)
@@ -533,7 +533,7 @@ void news_load_message (MAILSTREAM *stream,unsigned long msgno,long flags)
 	}
 	nlseen = T;		/* note newline seen */
 	break;
-      default:			/* ordinary chararacter */
+      default:			/* ordinary character */
 	i++;
 	nlseen = NIL;
 	break;
