@@ -1,4 +1,5 @@
 /* ========================================================================
+ * Copyright 2019 Eduardo Chappa
  * Copyright 2008-2009 Mark Crispin
  * ========================================================================
  */
@@ -73,7 +74,8 @@ typedef struct ssl_stream {
 #include "sslio.h"
 
 /* Function prototypes */
-const SSL_METHOD *ssl_connect_mthd(int flag);
+int ssl_disable_mask(int ssl_version, int direction);
+const SSL_METHOD *ssl_connect_mthd(int flag, int *min, int *max);
 static SSLSTREAM *ssl_start(TCPSTREAM *tstream,char *host,unsigned long flags);
 static char *ssl_start_work (SSLSTREAM *stream,char *host,unsigned long flags);
 static int ssl_open_verify (int ok,X509_STORE_CTX *ctx);
@@ -91,6 +93,41 @@ static long ssl_abort (SSLSTREAM *stream);
 
 static RSA *ssl_genkey (SSL_CTX_TYPE *con,int export,int keylength);
 
+typedef struct ssl_versions_s {
+        char *name;
+        int   version;
+} SSL_VERSIONS_S;
+
+int
+pith_ssl_encryption_version(char *s)
+{
+        SSL_VERSIONS_S ssl_versions[] = {
+        { "no_min", 0 },
+        { "ssl3",   SSL3_VERSION },
+        { "tls1",   TLS1_VERSION },
+        { "tls1_1", TLS1_1_VERSION },
+        { "tls1_2", TLS1_2_VERSION },
+#ifdef TLS1_3_VERSION
+        { "tls1_3", TLS1_3_VERSION },
+#endif /* TLS1_3_VERSION */
+        { "no_max", 0 },        /* set this last in the list */
+        { NULL, 0 },
+        };
+        int i;
+
+        if (s == NULL || *s == '\0')
+                return -1;
+
+        for (i = 0; ssl_versions[i].name != NULL; i++)
+                if (strcmp(ssl_versions[i].name, s) == 0)
+                        break;
+
+        if (strcmp(s, "no_max") == 0) i--;
+
+        return ssl_versions[i].name != NULL ? ssl_versions[i].version : -1;
+}
+
+
 
 /* Secure Sockets Layer network driver dispatch */
 
@@ -105,7 +142,8 @@ static struct ssl_driver ssldriver = {
   ssl_host,			/* return host name */
   ssl_remotehost,		/* return remote host name */
   ssl_port,			/* return port number */
-  ssl_localhost			/* return local host name */
+  ssl_localhost,		/* return local host name */
+  ssl_getsize			/* return needed number of bytes */
 };
 				/* non-NIL if doing SSL primary I/O */
 static SSLSTDIOSTREAM *sslstdio = NIL;
@@ -125,9 +163,9 @@ void ssl_onceonlyinit (void)
     if (stat ("/dev/urandom",&sbuf)) {
       strcpy(tmp, "SSLXXXXXX");
       while ((fd = mkstemp(tmp)) < 0) sleep (1);
-      unlink (tmp);		/* don't need the file */
       fstat (fd,&sbuf);		/* get information about the file */
       close (fd);		/* flush descriptor */
+      unlink (tmp);		/* don't need the file */
 				/* not great but it'll have to do */
       sprintf (tmp + strlen (tmp),"%.80s%lx%.80s%lx%lx%lx%lx%lx",
 	       tcp_serveraddr (),(unsigned long) tcp_serverport (),
@@ -173,32 +211,119 @@ SSLSTREAM *ssl_aopen (NETMBX *mb,char *service,char *usrbuf)
   return NIL;			/* don't use this mechanism with SSL */
 }
 
+typedef struct ssl_disable_s {
+  int   version;
+  int   disable_code;
+} SSL_DISABLE_S;
+        
+SSL_DISABLE_S ssl_disable[] = {
+    {SSL2_VERSION, SSL_OP_NO_SSLv2},
+    {SSL3_VERSION, SSL_OP_NO_SSLv3},
+    {TLS1_VERSION, SSL_OP_NO_TLSv1},
+    {TLS1_1_VERSION, SSL_OP_NO_TLSv1_1},
+    {TLS1_2_VERSION, SSL_OP_NO_TLSv1_2},
+#ifdef TLS1_3_VERSION
+    {TLS1_3_VERSION, SSL_OP_NO_TLSv1_3},
+#endif /* TLS1_3_VERSION */
+    {0, 0}
+};
+
+#define NUMBER_SSL_VERSIONS (sizeof(ssl_disable)/sizeof(ssl_disable[0]) - 1)
+
+/* returns the mask to disable a specific version.
+ * If version not found, returns 0.
+ * 
+ * Arguments: version, and direction.
+ * If direction is -1, returns mask to disable versions less than given version.
+ * If direction is +1, returns mask to disable versions bigger than given version.
+ */
+int ssl_disable_mask(int ssl_version, int direction)
+{
+  int rv = 0;
+  int i;
+  for(i = 0; ssl_disable[i].version != 0 
+		&& ssl_disable[i].version != ssl_version; i++);
+  if(i == 0 
+     || i == NUMBER_SSL_VERSIONS - 1 
+     || ssl_disable[i].version == 0) 
+    return rv;
+  i += direction; 	/* move in the direction */
+  for(; i >= 0 && i <= NUMBER_SSL_VERSIONS - 1; i += direction)
+     rv |= ssl_disable[i].disable_code;
+  return rv;
+}
+
+
 /* ssl_connect_mthd: returns a context pointer to the connection to
  * a ssl server
  */
-const SSL_METHOD *ssl_connect_mthd(int flag)
+const SSL_METHOD *ssl_connect_mthd(int flag, int *min, int *max)
 {
-#ifdef OPENSSL_1_1_0
-  if(flag & NET_TRYTLS1)
-    return TLS_client_method(); 
+  int client_request;
+  client_request = (flag & NET_TRYTLS1) ? TLS1_VERSION
+		 : (flag & NET_TRYTLS1_1) ? TLS1_1_VERSION
+		 : (flag & NET_TRYTLS1_2) ? TLS1_2_VERSION
+#ifdef TLS1_3_VERSION
+		 : (flag & NET_TRYTLS1_3) ? TLS1_3_VERSION
 #else
-  if(flag & NET_TRYTLS1)
-    return TLSv1_client_method(); 
-#endif /* OPENSSL_1_1_0 */
-#ifdef TLSV1_2
-  else if(flag & NET_TRYTLS1_1) 
-	return TLSv1_1_client_method();
-  else if(flag & NET_TRYTLS1_2) 
-	return TLSv1_2_client_method();
-#endif /* TLSV1_2 */
-#ifdef OPENSSL_1_1_0
-  else if(flag & NET_TRYDTLS1)
-	return DTLS_client_method();
+		 : (flag & NET_TRYTLS1_3) ? -2
+#endif
+		 : 0;
+
+  *min = *(int *) mail_parameters(NULL, GET_ENCRYPTION_RANGE_MIN, NULL);
+  *max = *(int *) mail_parameters(NULL, GET_ENCRYPTION_RANGE_MAX, NULL);
+
+  /* 
+   * if no special request, negotiate the maximum the client is configured
+   * to negotiate
+   */
+  if(client_request == 0)
+    client_request = *max;
+
+  if(client_request < *min || client_request > *max)
+    return NIL;		/* out of range? bail out */
+
+  /* Some Linux distributors seem to believe that it is ok to disable some of
+   * these methods for their users, so we have to test that every requested
+   * method has actually been compiled in into their openssl/libressl library.
+   * Oh well...
+   */
+#ifndef OPENSSL_1_1_0
+  if(client_request == SSL3_VERSION)
+#ifndef OPENSSL_NO_SSL3_METHOD
+     return SSLv3_client_method();
 #else
-  else if(flag & NET_TRYDTLS1)
-	return DTLSv1_client_method();
-#endif /* OPENSSL_1_1_0 */
-  else return SSLv23_client_method();
+     return NIL;
+#endif /* OPENSSL_NO_SSL3_METHOD */
+  else if(client_request == TLS1_VERSION)
+#ifndef OPENSSL_NO_TLS1_METHOD
+     return TLSv1_client_method();
+#else
+     return NIL;
+#endif /* OPENSSL_NO_TLS1_METHOD */
+  else if(client_request == TLS1_1_VERSION)
+#ifndef OPENSSL_NO_TLS1_1_METHOD
+     return TLSv1_1_client_method();
+#else
+     return NIL;
+#endif /* OPENSSL_NO_TLS1_1_METHOD */
+  else if(client_request == TLS1_2_VERSION)
+#ifndef OPENSSL_NO_TLS1_2_METHOD
+     return TLSv1_2_client_method();
+#else
+     return NIL;
+#endif /* OPENSSL_NO_TLS1_2_METHOD */
+#ifdef TLS1_3_VERSION	/* this is only reachable if TLS1_3 support exists */
+  else if(client_request == TLS1_3_VERSION)
+#ifndef OPENSSL_NO_TLS1_3_METHOD
+     return TLS_client_method();
+#else
+     return NIL;
+#endif /* #ifndef OPENSSL_NO_TLS1_2_METHOD */
+#endif /* TLS1_3_VERSION */
+#endif /* ifndef OPENSSL_1_1_0 */
+
+  return SSLv23_client_method();
 }
 
 /* Start SSL/TLS negotiations
@@ -267,6 +392,8 @@ static char *ssl_start_work (SSLSTREAM *stream,char *host,unsigned long flags)
   BIO *bio;
   X509 *cert;
   unsigned long sl,tl;
+  int min, max;
+  int masklow, maskhigh;
   char *s,*t,*err,tmp[MAILTMPLEN], buf[256];
   sslcertificatequery_t scq =
     (sslcertificatequery_t) mail_parameters (NIL,GET_SSLCERTIFICATEQUERY,NIL);
@@ -276,9 +403,12 @@ static char *ssl_start_work (SSLSTREAM *stream,char *host,unsigned long flags)
     (sslclientkey_t) mail_parameters (NIL,GET_SSLCLIENTKEY,NIL);
   if (ssl_last_error) fs_give ((void **) &ssl_last_error);
   ssl_last_host = host;
-  if (!(stream->context = SSL_CTX_new (ssl_connect_mthd(flags))))
+  if (!(stream->context = SSL_CTX_new (ssl_connect_mthd(flags, &min, &max))))
     return "SSL context failed";
   SSL_CTX_set_options (stream->context,0);
+  masklow = ssl_disable_mask(min, -1);
+  maskhigh = ssl_disable_mask(max, 1);
+  SSL_CTX_set_options(stream->context, masklow|maskhigh);
 				/* disable certificate validation? */
   if (flags & NET_NOVALIDATECERT)
     SSL_CTX_set_verify (stream->context,SSL_VERIFY_NONE,NIL);
@@ -313,6 +443,9 @@ static char *ssl_start_work (SSLSTREAM *stream,char *host,unsigned long flags)
 				/* create connection */
   if (!(stream->con = (SSL *) SSL_new (stream->context)))
     return "SSL connection failed";
+  if (host && !SSL_set_tlsext_host_name(stream->con, host)){
+    return "Server Name Identification (SNI) failed";
+  }
   bio = BIO_new_socket (stream->tcpstream->tcpsi,BIO_NOCLOSE);
   SSL_set_bio (stream->con,bio,bio);
   SSL_set_connect_state (stream->con);
@@ -371,39 +504,71 @@ static int ssl_open_verify (int ok,X509_STORE_CTX *ctx)
 
 static char *ssl_validate_cert (X509 *cert,char *host)
 {
-  int i,n;
-  char *s=NULL,*t,*ret;
+  int i,j,n, m = 0;
+  char *s=NULL,*t,*ret = NIL;
   void *ext;
   GENERAL_NAME *name;
   X509_NAME *cname;
   X509_NAME_ENTRY *e;
   char    buf[256];
 				/* make sure have a certificate */
-  if (!cert) ret = "No certificate from server";
-				/* and that it has a name */
-  else if (!(cname = X509_get_subject_name(cert))) ret = "No name in certificate";
-				/* locate CN */
-  else{
-     if((e = X509_NAME_get_entry(cname, X509_NAME_entry_count(cname)-1)) != NULL){
-       X509_NAME_get_text_by_OBJ(cname, X509_NAME_ENTRY_get_object(e), buf, sizeof(buf));
-       s = (char *) buf;
-     }
-     else s = NULL;
-  }
-  if (s != NULL) {
+  if (!cert) return "No certificate from server";
+				/* Method 1: locate CN */
+#ifndef OPENSSL_1_1_0
+  if (cert->name == NIL)
+     ret = "No name in certificate";
+  else if ((s = strstr (cert->name,"/CN=")) != NIL) {
+     m++; /* count that we tried this method */
+     if (t = strchr (s += 4,'/')) *t = '\0';
 				/* host name matches pattern? */
-    ret = ssl_compare_hostnames (host,s) ? NIL :
+     ret = ssl_compare_hostnames (host,s) ? NIL :
       "Server name does not match certificate";
+     if (t) *t = '/';		/* restore smashed delimiter */
 				/* if mismatch, see if in extensions */
-    if (ret && (ext = X509_get_ext_d2i (cert,NID_subject_alt_name,NIL,NIL)) &&
+     if (ret && (ext = X509_get_ext_d2i (cert,NID_subject_alt_name,NIL,NIL)) &&
 	(n = sk_GENERAL_NAME_num (ext)))
-      /* older versions of OpenSSL use "ia5" instead of dNSName */
-      for (i = 0; ret && (i < n); i++)
-	if ((name = sk_GENERAL_NAME_value (ext,i)) &&
+       /* older versions of OpenSSL use "ia5" instead of dNSName */
+       for (i = 0; ret && (i < n); i++)
+	 if ((name = sk_GENERAL_NAME_value (ext,i)) &&
 	    (name->type = GEN_DNS) && (s = name->d.ia5->data) &&
 	    ssl_compare_hostnames (host,s)) ret = NIL;
   }
-  else ret = "Unable to locate common name in certificate";
+#endif /* OPENSSL_1_1_0 */
+				/* Method 2, use cname */
+  if(m == 0 || ret != NIL){
+     cname = X509_get_subject_name(cert);
+     for(j = 0, ret = NIL; j < X509_NAME_entry_count(cname) && ret == NIL; j++){
+        if((e = X509_NAME_get_entry(cname, j)) != NULL){
+           X509_NAME_get_text_by_OBJ(cname, X509_NAME_ENTRY_get_object(e), buf, sizeof(buf));
+           s = (char *) buf;
+        }
+        else s = NIL;
+        if (s != NIL) {
+				/* host name matches pattern? */
+	   ret = ssl_compare_hostnames (host,s) ? NIL :
+		 "Server name does not match certificate";
+				/* if mismatch, see if in extensions */
+	   if (ret && (ext = X509_get_ext_d2i (cert,NID_subject_alt_name,NIL,NIL)) &&
+		(n = sk_GENERAL_NAME_num (ext)))
+	           /* older versions of OpenSSL use "ia5" instead of dNSName */
+	      for (i = 0; ret && (i < n); i++)
+		  if ((name = sk_GENERAL_NAME_value (ext,i)) &&
+		     (name->type = GEN_DNS) && (s = name->d.ia5->data) &&
+		     ssl_compare_hostnames (host,s)) ret = NIL;
+        }
+     }
+  }
+
+  if (ret == NIL
+#ifndef OPENSSL_1_1_0
+       && !cert->name
+#endif /* OPENSSL_1_1_0 */
+       && !X509_get_subject_name(cert))
+	ret = "No name in certificate";
+
+  if (ret == NIL && s == NIL) 
+	ret = "Unable to locate common name in certificate";
+
   return ret;
 }
 
@@ -466,7 +631,26 @@ char *ssl_getline (SSLSTREAM *stream)
   }
   return ret;
 }
-
+
+char *ssl_getsize (SSLSTREAM *stream, unsigned long size)
+{
+  char *ret = NIL;
+  unsigned long got = 0L, need = size, n;
+  
+  do {
+     if(!ssl_getdata (stream)) return ret;      /* return what we have */
+     n = stream->ictr < need ? stream->ictr : need;
+     fs_resize((void **) &ret, (got + n + 1)*sizeof(char));
+     memcpy(ret + got, stream->iptr, n);
+     ret[got+n] = '\0';
+     got  += n;   
+     need -= n;
+     stream->iptr += n;
+     stream->ictr -= n;
+  } while (need > 0);
+
+  return ret;
+}
 /* SSL receive line or partial line
  * Accepts: SSL stream
  *	    pointer to return size
