@@ -208,7 +208,7 @@ TCPSTREAM *tcp_open (char *host,char *service,unsigned long port)
 				&cleanup)) && !silent)
 	  mm_log (tmp,WARN);
 	(*bn) (BLOCK_NONE,NIL);
-      } while ((sock < 0) && s);/* repeat until success or no more addreses */
+      } while ((sock < 0) && s);/* repeat until success or no more addresses */
     }
     ip_nametoaddr (NIL,NIL,NIL,NIL,NIL,&cleanup);
   }
@@ -312,7 +312,7 @@ int tcp_socket_open (int family,void *adr,size_t adrlen,unsigned short port,
 	/* This used to be a zero-byte read(), but that crashes Solaris */
 				/* get socket status */
 	if(FD_ISSET(sock,&rfds))
-	   while (((i = *ctr = read (sock,tmp,0)) < 0) && (errno == EINTR));
+	   while (((i = *ctr = read (sock,tmp,1)) < 0) && (errno == EINTR));
       }	
       if (i <= 0) {		/* timeout or error? */
 	i = i ? errno : ETIMEDOUT;/* determine error code */
@@ -1063,6 +1063,40 @@ long tcp_isclienthost (char *host)
   return ret;
 }
 
+char *tcp_getsize (TCPSTREAM *stream, unsigned long size)
+{
+  char *ret = NIL;
+  unsigned long got = 0L, need = size, n;
+  int done = 0;
+
+  while(!done){
+     if(!tcp_getdata (stream)) return ret;	/* return what we have */
+     n = stream->ictr < need ? stream->ictr : need;
+     fs_resize((void **) &ret, got + n + 1);
+     memcpy(ret + got, stream->iptr, n);
+     ret[got+n] = '\0';
+     got  += n;
+     need -= n;
+     stream->iptr += n;
+     stream->ictr -= n;
+     if(need == 0L) done++;
+  }
+
+  return ret;
+}
+
 /* Following statement must be at end of this module */
 
 #undef fork			/* undo any use of vfork() */
+
+void tcp_end(void)
+{
+ if(rshcommand) fs_give((void **) &rshcommand);
+ if(rshpath) fs_give((void **) &rshpath);
+ if(sshcommand) fs_give((void **) &sshcommand);
+ if(sshpath) fs_give((void **) &sshpath);
+ if(myClientAddr) fs_give((void **) &myClientAddr);
+ if(myClientHost) fs_give((void **) &myClientHost);
+ if(myServerAddr) fs_give((void **) &myServerAddr);
+ if(myServerHost) fs_give((void **) &myServerHost);
+}
