@@ -5,7 +5,7 @@ static char rcsid[] = "$Id: display.c 1025 2008-04-08 22:59:38Z hubert@u.washing
 /*
  * ========================================================================
  * Copyright 2006-2008 University of Washington
- * Copyright 2013-2017 Eduardo Chappa
+ * Copyright 2013-2020 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -957,7 +957,7 @@ updext(void)
       lbound = w;
 
 
-    /* scan through the line outputing characters to the virtual screen
+    /* scan through the line outputting characters to the virtual screen
      * once we reach the left edge
      */
     vtmove(currow, -lbound);		/* start scanning offscreen */
@@ -2379,6 +2379,13 @@ ret:
 }
 
 
+void
+emlwwrite(char *utf8message, EML *eml)
+{
+  (*term.t_beep)();
+   emlwrite(utf8message, eml);
+}
+
 void
 emlwrite(char *utf8message, EML *eml)
 {
@@ -3370,14 +3377,20 @@ wstripe(int line, int column, char *utf8pmt, int key)
     ucs4pmt = utf8_to_ucs4_cpystr(utf8pmt);
     l = ucs4_strlen(ucs4pmt);
     while(1){
-	if(i >= term.t_ncol || col >= term.t_ncol || j >= l)
+	if(i >= term.t_ncol || col >= term.t_ncol || j >= l){
+	  if(lastc) free_color_pair(&lastc);
+	  if(ucs4pmt) fs_give((void **) &ucs4pmt);
 	  return;				/* equal strings */
+	}
 
 	if(ucs4pmt[j] == (UCS) key)
 	  j++;
 
-	if (pscr(line, i) == NULL)
+	if (pscr(line, i) == NULL){
+	  if(lastc) free_color_pair(&lastc);
+	  if(ucs4pmt) fs_give((void **) &ucs4pmt);
 	  return;
+	}
 	
 	if(pscr(line, i)->c != ucs4pmt[j]){
 	    if(j >= 1 && ucs4pmt[j-1] == (UCS) key)
@@ -3719,7 +3732,7 @@ update_scroll (void)
 	   
 	
     /*
-     * Count the number of lines in the current bufer.  Done when:
+     * Count the number of lines in the current buffer.  Done when:
      *
      *      when told to recount:           curbp->b_linecnt == -1
      *      when the top line changed:      curwp->w_linep != last_top_line
