@@ -3,7 +3,7 @@
  *
  * ========================================================================
  * Copyright 2006-2007 University of Washington
- * Copyright 2013-2017 Eduardo Chappa
+ * Copyright 2013-2020 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -31,7 +31,7 @@
 /*	Configuration options	*/
 
 #define CVMVAS  1	/* arguments to page forward/back in pages	*/
-#define	NFWORD	1	/* forward word jumps to begining of word	*/
+#define	NFWORD	1	/* forward word jumps to beginning of word	*/
 #define	TYPEAH	0	/* type ahead causes update to be skipped	*/
 #define	REVSTA	1	/* Status line appears in reverse video		*/
 
@@ -187,8 +187,8 @@ typedef struct  WINDOW {
         int	w_marko;                /* Byte offset for "mark"       */
         struct  LINE *w_imarkp;         /* INTERNAL Line with "mark"    */
         int	w_imarko;               /* INTERNAL "mark" byte offset  */
-        signed char w_toprow;           /* Origin 0 top row of window   */
-        signed char w_ntrows;           /* # of rows of text in window  */
+        int	w_toprow;               /* Origin 0 top row of window   */
+        int	w_ntrows;               /* # of rows of text in window  */
         char    w_force;                /* If NZ, forcing row.          */
         char    w_flag;                 /* Flags.                       */
 }       WINDOW;
@@ -319,7 +319,7 @@ typedef struct  {
         int     (*k_fp)();              /* Routine to handle it         */
 }       KEYTAB;
 
-/*      sturcture used for key menu painting         */
+/*      structure used for key menu painting         */
 
 typedef struct {
 	char	*name;			/* key to display (UTF-8)		*/
