@@ -5,7 +5,7 @@ static char rcsid[] = "$Id: main.c 1184 2008-12-16 23:52:15Z hubert@u.washington
 /*
  * ========================================================================
  * Copyright 2006-2008 University of Washington
- * Copyright 2013-2017 Eduardo Chappa
+ * Copyright 2013-2020 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -79,15 +79,17 @@ char *pico_args(int, char **, int *, int *, int *);
 void  pico_args_help(void);
 void  pico_vers_help(void);
 void  pico_display_args_err(char *, char **, int);
+#ifndef _WINDOWS
 PCOLORS *pico_set_global_colors(int, int, int, int, int, int, int, int, int, int, int, int, int, int, int, int, int, int, int, int, int, int, int);
 void  display_color_codes(void);
-
+#endif /* ! _WINDOWS */
 
 /* TRANSLATORS: An error message about an unknown flag (option)
    on the command line */
 char  args_pico_missing_flag[]  = N_("unknown flag \"%c\"");
 /* TRANSLATORS: error message about command line */
 char  args_pico_missing_arg[]   = N_("missing or empty argument to \"%c\" flag");
+char  args_pico_missing_arg_s[] = N_("missing or empty argument to \"%s\" flag");
 char  args_pico_missing_num[]   = N_("non numeric argument for \"%c\" flag");
 char  args_pico_missing_color[] = N_("missing color for \"%s\" flag");
 char  args_pico_missing_charset[] = N_("missing character set for \"%s\" flag");
@@ -128,11 +130,13 @@ N_("\t -kcs <keyboard_character_set> \tdefaults to display_character_set"),
 N_("\t -syscs\t\tuse system-supplied translation routines"),
 #endif	/* ! _WINDOWS */
 #ifdef	_WINDOWS
+N_("\t -dict \"dict1,dict2\" a comma separated list of dictionaries, e.g. en_US, de_DE, es_ES, etc."),
 N_("\t -cnf color \tforeground color"),
 N_("\t -cnb color \tbackground color"),
 N_("\t -crf color \treverse foreground color"),
 N_("\t -crb color \treverse background color"),
 #endif	/* _WINDOWS */
+#ifndef _WINDOWS
 N_("\t -color_code  \tdisplay number codes for different colors"),
 N_("\t -ncolors number \tnumber of colors for screen (8, 16, or 256)"),
 N_("\t -ntfc number \tnumber of color of foreground text"),
@@ -157,6 +161,7 @@ N_("\t -q3fc number \tnumber of color of foreground (text) of level three of quo
 N_("\t -q3bc number \tnumber of color of background of level three of quoted text"),
 N_("\t -sbfc number \tnumber of color of foreground of signature block text"),
 N_("\t -sbbc number \tnumber of color of background of signature block text"),
+#endif /* !_WINDOWS */
 N_("\t +[line#] \tLine - start on line# line, default=1"),
 N_("\t -v \t\tView - view file"),
 N_("\t -no_setlocale_collate\tdo not do setlocale(LC_COLLATE)"),
@@ -195,6 +200,8 @@ main(int argc, char *argv[])
 
 #ifndef _WINDOWS
     utf8_parameters(SET_UCS4WIDTH, (void *) pith_ucs4width);
+#else  /* _WINDOWS */
+    chosen_dict = -1;			/* do not commit any dictionary when starting */
 #endif /* _WINDOWS */
 
     set_input_timeout(600);
@@ -483,6 +490,7 @@ main(int argc, char *argv[])
     }
 }
 
+#ifndef _WINDOWS
 void
 display_color_codes(void)
 {
@@ -497,18 +505,18 @@ display_color_codes(void)
   (*term.t_open)();
   (*term.t_rev)(FALSE);
 
-  pico_toggle_color(1);
+  pico_toggle_color(0);
   if((ncolors = pico_count_in_color_table()) <= 0){
     fprintf(stderr, "%s", "Your screen does not support colors\r\n");
     exit(1);
   }
 
-
   if(term.t_ncol < 62 || term.t_nrow < 23){
     fprintf(stderr, "%s", "Screen must have at least 24 rows and 63 columns\r\n");
     exit(1);
   }
 
+  if(ncolors & 1) ncolors--;	/* eliminate transparent colors at this time */
 
   fprintf(stdout, "%s", "The code of a color is the number in the same row plus\r\n");
   fprintf(stdout, "%s", "the number in the same column as that color.\r\n\r\n");
@@ -521,18 +529,17 @@ display_color_codes(void)
       default : fprintf(stderr, "Unknown number of colors %d\n", ncolors); 
 	        exit(1);
 	        break;
-    }
+  }
 
-    if(ncolors != 256){
+  pico_toggle_color(1);
+  if(ncolors < 256){
       for(k = -1; 16*k < ncolors; k++){
 	for(l = -1; l < ncolors; l++){
 	   if(k == -1){
-		if(ncolors == 8){
-		   if(l == -1)
-		      fprintf(stdout, "%s", "    ");
-	   	   else 
-		      fprintf(stdout, "%3d", l);
-		}
+		if(l == -1)
+		   fprintf(stdout, "%s", "    ");
+		else
+		   fprintf(stdout, "%3d", l);
 	   }
 	   else{
 		if(l == -1){
@@ -551,12 +558,11 @@ display_color_codes(void)
 	   }
 	}
 	pico_toggle_color(0);
-	if(k == 0)
+	if(k == -1)
 	  fprintf(stdout, " (%d colors)", ncolors);
-	if(k != -1 || ncolors == 8)
-	  fprintf(stdout, "%s", "\r\n");
+	fprintf(stdout, "%s", "\r\n");
       }
-    } else {
+  } else {
       fprintf(stdout, "%s", "Codes for terminal with 256 colors:\r\n");
       a = 16;
       for(k = -1; 36*k < ncolors; k++){
@@ -610,9 +616,10 @@ display_color_codes(void)
 	pico_toggle_color(0);
 	fprintf(stdout, "%s", "\r\n");
       }
-    }
-    pico_set_colorp(lastc, PSC_NONE);
+  }
+  pico_set_colorp(lastc, PSC_NONE);
 }
+#endif /* ! _WINDOWS */
 
 
 /*
@@ -634,6 +641,7 @@ pico_args(int ac, char **av, int *starton, int *viewflag, int *setlocale_collate
     int   c, usage = 0;
     char *str;
     char  tmp_1k_buf[1000];     /* tmp buf to contain err msgs  */ 
+#ifndef _WINDOWS
     int ncolors, ntfc, ntbc, rtfc, rtbc;
     int tbfc, tbbc, klfc, klbc, knfc, knbc, stfc, stbc, prfc, prbc;
     int q1fc, q1bc, q2fc, q2bc, q3fc, q3bc, sbfc, sbbc;
@@ -642,6 +650,8 @@ pico_args(int ac, char **av, int *starton, int *viewflag, int *setlocale_collate
     ntfc = ntbc = rtfc = rtbc = tbfc = tbbc = klfc = klbc = knfc = 
     knbc = stfc = stbc = prfc = prbc = q1fc = q1bc = q2fc = q2bc = 
     q3fc = q3bc = sbfc = sbbc = -1;
+#endif /* ! _WINDOWS */
+
 Loop:
     /* while more arguments with leading - or + */
     while(--ac > 0 && (**++av == '-' || **av == '+')){
@@ -675,6 +685,7 @@ Loop:
 	if(strcmp(*av, "version") == 0){
 	    pico_vers_help();
 	}
+#ifndef	_WINDOWS     /* color configuration disabled in Windows  at this time */
 	else if(strcmp(*av, "ntfc") == 0
 		|| strcmp(*av, "ntbc") == 0
 		|| strcmp(*av, "rtfc") == 0
@@ -749,10 +760,11 @@ Loop:
 	  }
 	  goto Loop;
 	}
-	else if(strcmp(*av, "color_codes") == 0){
+	else if(strcmp(*av, "color_code") == 0){
 	   display_color_codes();
 	   exit(0);
 	}
+#endif /* ! _WINDOWS */
 	else if(strcmp(*av, "no_setlocale_collate") == 0){
 	    *setlocale_collate = 0;
 	    goto Loop;
@@ -764,6 +776,42 @@ Loop:
 	}
 #endif	/* ! _WINDOWS */
 #ifdef	_WINDOWS
+        else if(strcmp(*av, "dict") == 0){
+	   char *cmd = *av; /* save it to use below */
+	   str = *++av;
+	   if(--ac){
+	     int i = 0;
+	     char *s;
+#define MAX_DICTIONARY	10
+	     while(str && *str){
+	        if(dictionary == NULL){
+		   dictionary = fs_get((MAX_DICTIONARY + 1)*sizeof(char *));
+		   memset((void *) dictionary, 0, (MAX_DICTIONARY+1)*sizeof(char *));
+		   if(dictionary == NULL)
+		     goto Loop;		/* get out of here */
+		}
+		if((s = strpbrk(str, " ,")) != NULL)
+		   *s++ = '\0';
+		dictionary[i] = fs_get(strlen(str) + 1);
+		strcpy(dictionary[i++], str);
+		if(s != NULL)
+		   for(; *s && (*s == ' ' || *s == ','); s++);
+		else
+		   goto Loop;
+		if(i == MAX_DICTIONARY + 1)
+		  goto Loop;
+		else
+		  str = s;
+	     }
+	   }
+	   else{
+		snprintf(tmp_1k_buf, sizeof(tmp_1k_buf), _(args_pico_missing_arg_s), cmd);
+		pico_display_args_err(tmp_1k_buf, NULL, 1);
+	        usage++;
+	   }
+
+	   goto Loop;
+	}
 	else if(strcmp(*av, "cnf") == 0
 	   || strcmp(*av, "cnb") == 0
 	   || strcmp(*av, "crf") == 0
@@ -974,12 +1022,14 @@ Loop:
     if(usage)
       pico_args_help();
 
+#ifndef _WINDOWS
     Pcolors = pico_set_global_colors(ncolors, ntfc, ntbc, rtfc, rtbc,
 		tbfc, tbbc, klfc, klbc, knfc, knbc, stfc, stbc, prfc, prbc,
 		q1fc, q1bc, q2fc, q2bc, q3fc, q3bc, sbfc, sbbc);
 
     if(Pcolors)
        pico_toggle_color(1);
+#endif /* ! _WINDOWS */
 
     /* return the first filename for editing */
     if(ac > 0)
@@ -989,6 +1039,7 @@ Loop:
 }
 
 
+#ifndef _WINDOWS
 PCOLORS *
 pico_set_global_colors(int nc, int ntfg, int ntbg, int rtfg, int rtbg,
 	int tbfg, int tbbg, int klfg, int klbg,
@@ -1109,6 +1160,7 @@ pico_set_global_colors(int nc, int ntfg, int ntbg, int rtfg, int rtbg,
 
   return pcolors;
 }
+#endif /* ! _WINDOWS */
 
 #ifdef	_WINDOWS
 /*
