@@ -5,7 +5,7 @@ static char rcsid[] = "$Id: pico.c 921 2008-01-31 02:09:25Z hubert@u.washington.
 /*
  * ========================================================================
  * Copyright 2006-2008 University of Washington
- * Copyright 2013-2017 Eduardo Chappa
+ * Copyright 2013-2020 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -705,7 +705,7 @@ abort_composer(int f, int n)
 	return(TRUE);
 
       case ABORT:
-	emlwrite(_("\007Cancel Cancelled"), NULL);
+	emlwwrite(_("Cancel Cancelled"), NULL);
 	break;
 
       default:
@@ -746,7 +746,7 @@ wquit(int f, int n)
 
 	/* First, make sure there are no outstanding problems */ 
 	if(AttachError()){
-	    emlwrite(_("\007Problem with attachments!  Fix errors or delete attachments."), NULL);
+	    emlwwrite(_("Problem with attachments!  Fix errors or delete attachments."), NULL);
 	    return(FALSE);
 	}
 
@@ -804,8 +804,17 @@ wquit(int f, int n)
         }
 
 	if(s == TRUE){
-	    if(filewrite(0,1) == TRUE)
+	    if(filewrite(0,1) == TRUE){
+#ifdef _WINDOWS
+	      if(dictionary != NULL){
+	        int i;
+		for(i = 0; dictionary[i] != NULL; i++)
+		   fs_give((void **)&dictionary[i]);
+		fs_give((void **)dictionary);
+	      }
+#endif /* _WINDOWS */
 	      wquit(1, 0);
+	    }
 	}
 	else if(s == ABORT){
 	    emlwrite(_("Exit cancelled"), NULL);
@@ -1247,7 +1256,7 @@ doubleclick = (lrow == row && lcol == col
 		       && time(0) < (lastcalled + 2));
 	lastcalled  = time(0);
 #endif
-	lheader	    = FALSE;	/* Rember mouse down position. */
+	lheader	    = FALSE;	/* Remember mouse down position. */
 	levent	    = mevent;
 	lrow	    = row;
 	lcol	    = col;
@@ -1918,6 +1927,26 @@ breplace(void *w)
     curwp->w_flag |= WFHARD;
 }
 
+void
+free_pico_module_globals(void)
+{
+  int i;
+
+#ifdef MOUSE
+  for(i = 0; i < 12; i++){
+    if(menuitems[i].kncp)
+        free_color_pair(&menuitems[i].kncp);
+    if(menuitems[i].klcp)
+        free_color_pair(&menuitems[i].klcp);
+    if(menuitems[i].label){
+	free((void *) menuitems[i].label);
+	menuitems[i].label = NULL;
+    }
+  }
+#endif /* MOUSE */
+
+}
+
 
 #ifdef	_WINDOWS
 /*
