@@ -5,7 +5,7 @@ static char rcsid[] = "$Id: bldaddr.c 769 2007-10-24 00:15:40Z hubert@u.washingt
 /*
  * ========================================================================
  * Copyright 2006-2007 University of Washington
- * Copyright 2013-2017 Eduardo Chappa
+ * Copyright 2013-2020 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -1261,3 +1261,9 @@ free_privatetop(PrivateTop **pt)
 	fs_give((void **)pt);
     }
 }
+
+void
+free_bldaddr_module_globals(void)
+{
+  if(last_fcc_used) fs_give((void **)&last_fcc_used);
+}
