@@ -4,7 +4,7 @@ static char rcsid[] = "$Id: utf8.c 1184 2008-12-16 23:52:15Z hubert@u.washington
 
 /*
  * ========================================================================
- * Copyright 2013-2017 Eduardo Chappa
+ * Copyright 2013-2020 Eduardo Chappa
  * Copyright 2006-2008 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -92,7 +92,7 @@ wcellwidth(UCS ucs)
 	    return((w & U4W_ERROR) ? -1 : w);
 	}
     }
-#ifndef _WINDOWS
+#if !defined(_WINDOWS) && HAVE_WCWIDTH
     else
       return(wcwidth((wchar_t) ucs));
 #else
@@ -100,11 +100,14 @@ wcellwidth(UCS ucs)
 #endif
 }
 
-/* ambiguous width zone character function */
+/* ambiguous width zone character function. We use the Windows code until
+ * we find a better way to do it in general.
+ */
 int
 pith_ucs4width(UCS ucs)
 {
-#ifndef _WINDOWS
+  return (ucs >= 0x2100) ? 2 : 1; 
+#if !defined(_WINDOWS) && HAVE_WCWIDTH
   return wcwidth((wchar_t) ucs);
 #else
   return (ucs >= 0x2100) ? 2 : 1; 
@@ -280,6 +283,10 @@ convert_to_utf8(char *str, char *fromcharset, int flags)
 	    }
 	    /* else no conversion necessary */
 
+	    if(result.data)
+	      fs_give((void **) &result.data);
+	    result.size = 0;
+
 	    return(ret);
 	}
 
@@ -303,9 +310,10 @@ char *
 convert_to_locale(char *utf8str)
 {
 #define CHNK 500
-    char *inp, *retp, *ret = NULL;
+    char *inp, *ret = NULL;
     CBUF_S cb;
-    int r, alloced;
+    int alloced;
+    size_t i = 0;
 
     if(native_utf8 || !utf8str || !utf8str[0])
       return(NULL);
@@ -316,7 +324,6 @@ convert_to_locale(char *utf8str)
 
     alloced = CHNK;
     ret = (char *) fs_get(alloced * sizeof(char));
-    retp = ret;
 
     /*
      * There's gotta be a better way to do this but utf8_to_locale was
@@ -330,20 +337,18 @@ convert_to_locale(char *utf8str)
 	 * enough room for the next wide characters worth of output chars
 	 * and allocate more space if not.
 	 */
-	if((alloced - (retp-ret)) < MAX(MB_LEN_MAX,32)){
+        if((alloced - i) < MAX(MB_LEN_MAX,32)){
 	    alloced += CHNK;
 	    fs_resize((void **) &ret, alloced * sizeof(char));
 	}
 
-	r = utf8_to_locale((int) *inp++, &cb,
-			   (unsigned char *) retp, alloced-(retp-ret));
-
-	retp += r;
+        i += utf8_to_locale((int) *inp++, &cb,
+                           (unsigned char *) &ret[i], alloced - i);
     }
 
-    *retp = '\0';
+    fs_resize((void **) &ret, i + 1);
 
-    fs_resize((void **) &ret, strlen(ret)+1);
+    ret[i] = '\0';
 
     return(ret);
 }
