@@ -2,7 +2,7 @@
  * $Id: conf.h 1155 2008-08-21 18:33:21Z hubert@u.washington.edu $
  *
  * ========================================================================
- * Copyright 2013-2017 Eduardo Chappa
+ * Copyright 2013-2020 Eduardo Chappa
  * Copyright 2006-2008 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -263,6 +263,8 @@
 #define GLO_REMOTE_ABOOK_HISTORY     vars[V_REMOTE_ABOOK_HISTORY].global_val.p
 #define VAR_REMOTE_ABOOK_VALIDITY    vars[V_REMOTE_ABOOK_VALIDITY].current_val.p
 #define GLO_REMOTE_ABOOK_VALIDITY    vars[V_REMOTE_ABOOK_VALIDITY].global_val.p
+#define GLO_ENCRYPTION_RANGE         vars[V_ENCRYPTION_RANGE].global_val.p
+#define VAR_ENCRYPTION_RANGE	     vars[V_ENCRYPTION_RANGE].current_val.p
   /* Elm style save is obsolete in Pine 3.81 (see saved msg name rule) */
 #define VAR_ELM_STYLE_SAVE           vars[V_ELM_STYLE_SAVE].current_val.p
 #define GLO_ELM_STYLE_SAVE           vars[V_ELM_STYLE_SAVE].global_val.p
@@ -310,6 +312,7 @@
 #define VAR_TCPREADWARNTIMEO	     vars[V_TCPREADWARNTIMEO].current_val.p
 #define VAR_TCPWRITEWARNTIMEO	     vars[V_TCPWRITEWARNTIMEO].current_val.p
 #define VAR_TCPQUERYTIMEO	     vars[V_TCPQUERYTIMEO].current_val.p
+#define VAR_QUITQUERYTIMEO	     vars[V_QUITQUERYTIMEO].current_val.p
 #define VAR_RSHOPENTIMEO	     vars[V_RSHOPENTIMEO].current_val.p
 #define VAR_RSHPATH		     vars[V_RSHPATH].current_val.p
 #define VAR_RSHCMD		     vars[V_RSHCMD].current_val.p
@@ -751,6 +754,10 @@
 					 &(n), 5, 30000, 0, (e),	  \
 					  (el), 			  \
 					"Tcp-Query-Timeout")
+#define	SVAR_QUIT_QUERY_TIMEO(ps,n,e,el) strtoval((ps)->VAR_QUITQUERYTIMEO, 	  \
+					 &(n), 0, 30000, 0, (e),	  \
+					  (el), 			  \
+					"Reopen-Folder-Timeout")
 #define	SVAR_RSH_OPEN(ps,n,e,el) strtoval((ps)->VAR_RSHOPENTIMEO, 	  \
 					 &(n), 5, 30000, 0, (e),	  \
 					  (el), 			  \
@@ -829,7 +836,7 @@ struct sm_folder {
 #define	CONF_TXT_T	char
 
 
-/* exported protoypes */
+/* exported prototypes */
 void       init_init_vars(struct pine *);
 void       init_pinerc(struct pine *, char **);
 void       init_vars(struct pine *, void (*)(struct pine *, char **));
