@@ -2,7 +2,7 @@
  * $Id: conftype.h 1155 2008-08-21 18:33:21Z hubert@u.washington.edu $
  *
  * ========================================================================
- * Copyright 2013-2017 Eduardo Chappa
+ * Copyright 2013-2020 Eduardo Chappa
  * Copyright 2006-2008 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -161,6 +161,7 @@ typedef	enum {    V_PERSONAL_NAME = 0
 		, V_TCPREADWARNTIMEO
 		, V_TCPWRITEWARNTIMEO
 		, V_TCPQUERYTIMEO
+		, V_QUITQUERYTIMEO
 		, V_RSHCMD
 		, V_RSHPATH
 		, V_RSHOPENTIMEO
@@ -170,12 +171,14 @@ typedef	enum {    V_PERSONAL_NAME = 0
 		, V_NEW_VER_QUELL
 		, V_DISABLE_DRIVERS
 		, V_DISABLE_AUTHS
+		, V_ENCRYPTION_RANGE
 		, V_REMOTE_ABOOK_METADATA
 		, V_REMOTE_ABOOK_HISTORY
 		, V_REMOTE_ABOOK_VALIDITY
 		, V_PRINTER
 		, V_PERSONAL_PRINT_COMMAND
 		, V_PERSONAL_PRINT_CATEGORY
+		, V_XOAUTH2_INFO
 		, V_PATTERNS		/* obsolete */
 		, V_PAT_ROLES
 		, V_PAT_FILTS
@@ -357,7 +360,9 @@ typedef enum {
 	F_AUTO_INCLUDE_IN_REPLY,
 	F_DISABLE_CONFIG_SCREEN,
 	F_DISABLE_PASSWORD_CACHING,
+#ifdef LOCAL_PASSWD_CACHE
 	F_DISABLE_PASSWORD_FILE_SAVING,
+#endif /* LOCAL_PASSWD_CACHE */
 	F_DISABLE_REGEX,
 	F_DISABLE_PASSWORD_CMD,
 	F_DISABLE_UPDATE_CMD,
@@ -777,7 +782,7 @@ typedef struct smime_stuff {
 #endif /* SMIME */
 
 
-/* exported protoypes */
+/* exported prototypes */
 
 
 #endif /* PITH_CONFTYPE_INCLUDED */
