@@ -4,7 +4,7 @@ static char rcsid[] = "$Id: mimedesc.c 1142 2008-08-13 17:22:21Z hubert@u.washin
 
 /*
  * ========================================================================
- * Copyright 2013-2017 Eduardo Chappa
+ * Copyright 2013-2020 Eduardo Chappa
  * Copyright 2006-2008 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -252,7 +252,8 @@ describe_mime(struct mail_bodystruct *body, char *prefix, int num,
 	 * be expensive to test...
 	 */
 	if((body->type == TYPETEXT && !named)
-	   || MIME_VCARD(body->type,body->subtype)){
+	   || MIME_VCARD(body->type,body->subtype)
+	   || MIME_VCALENDAR(body->type, body->subtype)){
 	    a->test_deferred = 1;
 	    a->can_display = MCD_INTERNAL;
 	}
@@ -264,7 +265,8 @@ describe_mime(struct mail_bodystruct *body, char *prefix, int num,
 	/*
 	 * Deferred means we can display it
 	 */
-	a->shown = ((a->can_display & MCD_INTERNAL)
+	a->shown = MIME_VCALENDAR(body->type, body->subtype)
+		   || ((a->can_display & MCD_INTERNAL)
 		    && !MIME_VCARD(body->type,body->subtype)
 		    && (!named || multalt
 			|| (body->type == TYPETEXT && num == 1
@@ -485,7 +487,7 @@ static struct set_names {
     {"ISO-8859-14",		"Latin 8 (Celtic)"},
     {"ISO-8859-15",		"Latin 9 (Euro)"},
     {"KOI8-R",			"Latin & Russian"},
-    {"KOI8-U",			"Latin & Ukranian"},
+    {"KOI8-U",			"Latin & Ukrainian"},
     {"VISCII",			"Latin & Vietnamese"},
     {"GB2312",			"Latin & Simplified Chinese"},
     {"BIG5",			"Latin & Traditional Chinese"},
@@ -504,7 +506,7 @@ static struct set_names {
 
 
 /*----------------------------------------------------------------------
-  Return a nicely formatted discription of the type of the part
+  Return a nicely formatted description of the type of the part
  ----*/
 
 char *
@@ -734,7 +736,7 @@ fcc_size_guess(struct mail_bodystruct *body)
 	     * is a per-line increase in that because of the CRLFs and
 	     * because the number of characters in the line might not
 	     * be a factor of 3. So push it up by 3/2 instead. This still
-	     * won't catch all the cases. In particular, attachements with
+	     * won't catch all the cases. In particular, attachments with
 	     * lots of short lines (< 10) will expand by more than that,
 	     * but that's ok since this is an optimization. That's why
 	     * so_cs_puts uses the 3/2 factor when it does a resize, so
