@@ -2,7 +2,7 @@
  * $Id: pineelt.h 1142 2008-08-13 17:22:21Z hubert@u.washington.edu $
  *
  * ========================================================================
- * Copyright 2013-2017 Eduardo Chappa
+ * Copyright 2013-2020 Eduardo Chappa
  * Copyright 2006 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -41,6 +41,7 @@ typedef struct pine_elt {
 	PINETHRD_S  *pthrd;
 	PARTEX_S    *exceptions;
 	ICE_S       *ice;
+	char	    *firsttext;
 	/* per-message pine state bits */
 	unsigned int hidden:1;
 	unsigned int excluded:1;
@@ -54,7 +55,7 @@ typedef struct pine_elt {
 } PINELT_S;
 
 
-/* exported protoypes */
+/* exported prototypes */
 void	    msgno_free_exceptions(PARTEX_S **);
 
 
