@@ -5,7 +5,7 @@ static char rcsid[] = "$Id: save.c 1204 2009-02-02 19:54:23Z hubert@u.washington
 /*
  * ========================================================================
  * Copyright 2006-2009 University of Washington
- * Copyright 2013-2017 Eduardo Chappa
+ * Copyright 2013-2020 Eduardo Chappa
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -1573,7 +1573,7 @@ save_ex_mask_types(char *hdr, long unsigned int *len, gf_io_t pc)
     char *s = NULL;
 
     if(!struncmp(hdr, "content-type:", 13))
-      s = "Content-Type: Text/Plain; charset=US-ASCII\015\012X-";
+      s = "Content-Type: Text/Plain; charset=UTF-8\015\012X-";
     else if(!struncmp(hdr, "content-description:", 20))
       s = "Content-Description: Deleted Attachment\015\012X-";
     else if(!struncmp(hdr, "content-transfer-encoding:", 26)
@@ -1616,6 +1616,12 @@ save_ex_explain_parts(struct mail_bodystruct *body, int depth, long unsigned int
     unsigned long ilen;
     char *name = parameter_val(body->parameter, "name");
 
+    if(!name){
+      if(body->disposition.type && 
+	 !strucmp(body->disposition.type, "ATTACHMENT"))
+      name = parameter_val(body->disposition.parameter, "filename");
+    }
+
     if(body->type == TYPEMULTIPART) {   /* multipart gets special handling */
 	PART *part = body->nested.part;	/* first body part */
 
@@ -1625,7 +1631,8 @@ save_ex_explain_parts(struct mail_bodystruct *body, int depth, long unsigned int
 		    depth, depth, " ", body_type_names(body->type),
 		    MAILTMPLEN-300, body->subtype ? body->subtype : "Unknown",
 		    name ? " (Name=\"" : "",
-		    name ? name : "",
+		    name ? (char *) rfc1522_decode_to_utf8((unsigned char *)tmp_20k_buf,
+				SIZEOF_20KBUF, name) : "",
 		    name ? "\")" : "");
 	    if(!save_ex_output_line(tmp, len, pc))
 	      return(0);
@@ -1641,7 +1648,8 @@ save_ex_explain_parts(struct mail_bodystruct *body, int depth, long unsigned int
 		    body_type_names(body->type),
 		    MAILTMPLEN-300, body->subtype ? body->subtype : "Unknown",
 		    name ? " (Name=\"" : "",
-		    name ? name : "",
+		    name ? (char *) rfc1522_decode_to_utf8((unsigned char *)tmp_20k_buf,
+				SIZEOF_20KBUF, name) : "",
 		    name ? "\")" : "");
 	}
 
@@ -1664,7 +1672,8 @@ save_ex_explain_parts(struct mail_bodystruct *body, int depth, long unsigned int
 		body_type_names(body->type), 
 		MAILTMPLEN-300, body->subtype ? body->subtype : "Unknown",
 		name ? " (Name=\"" : "",
-		name ? name : "",
+		name ? (char *) rfc1522_decode_to_utf8((unsigned char *)tmp_20k_buf,
+				SIZEOF_20KBUF, name) : "",
 		name ? "\")" : "",
 		comatose((body->encoding == ENCBASE64)
 			   ? ((body->size.bytes * 3)/4)
@@ -1702,7 +1711,7 @@ save_ex_output_line(char *line, long unsigned int *len, gf_io_t pc)
 /*----------------------------------------------------------------------
    Save() helper function to create canonical date string from given header
 
-   Args: date -- buf to recieve canonical date string
+   Args: date -- buf to receive canonical date string
 	 header -- rfc822 header to fish date string from
 
  Result: date filled with canonicalized date in header, or null string
@@ -1757,7 +1766,7 @@ save_msg_stream(CONTEXT_S *context, char *folder, int *we_opened)
 
 
 /*----------------------------------------------------------------------
-    Offer to create a non-existant folder to copy message[s] into
+    Offer to create a non-existent folder to copy message[s] into
 
    Args: context -- context to create folder in
 	 folder -- name of folder to create
