@@ -4,7 +4,7 @@ static char rcsid[] = "$Id: smkeys.c 1266 2009-07-14 18:39:12Z hubert@u.washingt
 
 /*
  * ========================================================================
- * Copyright 2013-2017 Eduardo Chappa
+ * Copyright 2013-2020 Eduardo Chappa
  * Copyright 2008 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -95,17 +95,19 @@ create_master_password(char *pass, size_t passlen, int first_time)
 
   for(trial = 0; trial < MAXTRIAL; trial++){
     snprintf(prompt, sizeof(prompt), 
-		_("Create master password \(attempt %d of %d): "), trial+1, MAXTRIAL);
+		_("Create master password (attempt %d of %d): "), trial+1, MAXTRIAL);
     prompt[sizeof(prompt)- 1] = '\0';
     pass[0] = '\0';
-    do { 
+    do {
+      /* rv == 1 means cancel */
       rv = (pith_smime_enter_password)(prompt, pass, passlen);
-      if(password_policy_check(pass) == 0)
+      if(rv == 1 || password_policy_check(pass) == 0)
 	 pass[0] = '\0';
-    } while ((rv !=0 && rv !=1 && rv > 0) || pass[0] == '\0');
+      if(rv == 1) return 0;
+    } while ((rv != 0  && rv != 1) || (rv == 0 && pass[0] == '\0'));
 
     snprintf(prompt, sizeof(prompt), 
-		_("Confirm master password \(attempt %d of %d): "), trial+1, MAXTRIAL);
+		_("Confirm master password (attempt %d of %d): "), trial+1, MAXTRIAL);
     prompt[sizeof(prompt)- 1] = '\0';
     passbackup[0] = '\0';
     do { 
@@ -295,13 +297,19 @@ setup_certs_backup_by_type(WhichCerts ctype)
    int rv = 0; 	/* assume success */
    int len;
    int i, done;
-   char *d;
+   char *d, *fname;
    char p[MAXPATH+1];	/* path to where the backup is */
    char buf[MAXPATH+1], buf2[MAXPATH+1];
    struct stat sbuf;
    CertList *data, *cl;
+#ifndef _WINDOWS
    DIR *dirp;   
    struct dirent *df;	/* file in the directory */
+#else /* _WINDOWS */
+    struct _finddata_t dbuf;
+    char bufn[_MAX_PATH + 4];
+    long findrv;
+#endif /* !_WINDOWS */
    CertList *cert, *cl2;
    X509 *x;
    BIO *in;
@@ -405,64 +413,76 @@ setup_certs_backup_by_type(WhichCerts ctype)
 	/* Here is the plan: read the backup directory (in the variable "p")
 	 * and attempt to add it. If already there, skip it; otherwise continue
 	 */
+#ifndef _WINDOWS
+	if ((dirp = opendir(p)) != NULL) {
+		while ((df = readdir(dirp)) != NULL) {
+			fname = df->d_name;
 
-	if((dirp = opendir(p)) != NULL){
-	   while((df=readdir(dirp)) != NULL){
-	      if(df->d_name && *df->d_name == '.')	/* no hidden files here */
-		continue;
+			if (fname && *fname == '.')	/* no hidden files here */
+				continue;
+#else
+	snprintf(bufn, sizeof(bufn), "%s%s*.*", p, (p[strlen(p) - 1] == '\\') ? "" : "\\");
+	bufn[sizeof(bufn) - 1] = '\0';
+	if ((findrv = _findfirst(bufn, &dbuf)) >= 0) {
+		do {
+			fname = fname_to_utf8(dbuf.name);
+#endif /* ! _WINDOWS */
+			/* make sure that we have a file */
+			snprintf(buf2, sizeof(buf2), "%s%s%s", p, S_FILESEP, fname);
+			buf2[sizeof(buf2) - 1] = '\0';
+			if (our_stat(buf2, &sbuf) == 0
+				&& (sbuf.st_mode & S_IFMT) != S_IFREG)
+				continue;
 
-	      /* make sure that we have a file */
-	      snprintf(buf2, sizeof(buf2), "%s%s%s", p, S_FILESEP, df->d_name);
-	      buf2[sizeof(buf2)-1] = '\0';
-	      if(our_stat(buf2, &sbuf) == 0 
-		  && (sbuf.st_mode & S_IFMT) != S_IFREG)
-	        continue;
+			/* make sure it is not already in the list */
+			for (cl = data; cl; cl = cl->next)
+				if (strcmp(cl->name, fname) == 0)
+					break;
+			if (cl != NULL)
+				continue;
 
-	      /* make sure it is not already in the list */
-	      for(cl = data; cl; cl = cl->next)
-		if(strcmp(cl->name, df->d_name) == 0)
-		   break;
-	      if(cl != NULL)
-		continue;
+			/* ok, if it is not in the list, and it is a certificate. Add it */
+			switch (ctype) {
+			case Public:
+			case CACert:
+				if ((in = BIO_new_file(buf2, "r")) != 0) {
+					x = PEM_read_bio_X509(in, NULL, NULL, NULL);
+					if (x) { /* for now copy this information */
+						cert = smime_X509_to_cert_info(x, fname);
+						/* we will use the cert->data.md5 variable to find a backup
+						   certificate, not the name */
+						cert->next = data;
+						data = cert;
+					}
+					BIO_free(in);
+				}
+				break;
 
-	      /* ok, if it is not in the list, and it is a certificate. Add it */
-	      switch(ctype){
-		case Public:
-		case CACert:
-			if((in = BIO_new_file(buf2, "r"))!=0){
-			  x = PEM_read_bio_X509(in, NULL, NULL, NULL);
-			  if(x){ /* for now copy this information */
-			    cert = smime_X509_to_cert_info(x, df->d_name);
-			    /* we will use the cert->data.md5 variable to find a backup 
-			       certificate, not the name */
-			    cert->next = data;
-			    data = cert;
-			  }
-			  BIO_free(in);
-			}
-			break;
-
-		case Private:
-			/* here we must check it is a key of some cert....*/
-			break;
-
-		default: alpine_panic("Bad ctype (1)");
-	      } /* end switch */
-	   }
-	   closedir(dirp);
-	}
+			case Private:
+				/* here we must check it is a key of some cert....*/
+				break;
 
+			default: alpine_panic("Bad ctype (1)");
+			} /* end switch */
+#ifndef _WINDOWS
+		}
+		closedir(dirp);
+#else /* _WINDOWS */
+	} while (_findnext(findrv, &dbuf) == 0);
+	_findclose(findrv);
+#endif /* ! _WINDOWS */
+		}
 	/* Now that we are here, we have all the information in the backup
 	 * directory
 	 */
 
-	switch(ctype){
-	   case Public : ps_global->smime->backuppubliccertlist = data; break;
-	   case Private: ps_global->smime->backupprivatecertlist = data; break;
-	   case CACert : ps_global->smime->backupcacertlist = data; break;
-	   default : alpine_panic("Bad ctype (n)");
+	switch (ctype) {
+	case Public: ps_global->smime->backuppubliccertlist = data; break;
+	case Private: ps_global->smime->backupprivatecertlist = data; break;
+	case CACert: ps_global->smime->backupcacertlist = data; break;
+	default: alpine_panic("Bad ctype (n)");
+	}
 	}
-     }
    } else if(SMHOLDERTYPE(ctype) == Container){
     
    } /* else APPLEKEYCHAIN */
@@ -617,7 +637,8 @@ smime_get_date(const ASN1_TIME *tm)
    char date[MAILTMPLEN];
    char buf[MAILTMPLEN];
    char *m, *d, *t, *y, *z;
-   struct      date smd;
+   int len;
+   struct date smd;
    struct tm smtm;
 
    (void) BIO_reset(mb);
@@ -625,7 +646,8 @@ smime_get_date(const ASN1_TIME *tm)
      return cpystr(_("Invalid"));
 
    (void) BIO_flush(mb);
-   BIO_read(mb, iobuf, sizeof(iobuf));
+   len = BIO_read(mb, iobuf, sizeof(iobuf));
+   iobuf[len-1] = '\0';
 
   /* openssl returns the date in the format:
    *	"MONTH (as name) DAY (as number) TIME(hh:mm:ss) YEAR GMT"
@@ -658,6 +680,7 @@ smime_get_date(const ASN1_TIME *tm)
       snprintf(buf, sizeof(buf), "%s/%s/%s", m, d, y + strlen(y) - 2);
    buf[sizeof(buf)-1] = '\0';
 
+   BIO_free(mb);
    return cpystr(buf);
 }
 
@@ -667,20 +690,36 @@ smime_get_date(const ASN1_TIME *tm)
 int
 add_certs_in_dir(X509_LOOKUP *lookup, char *path, char *ext, CertList **cdata)
 {
-    char buf[MAXPATH];
+    char buf[MAXPATH], *fname;
+#ifndef _WINDOWS
     struct direct *d;
-    DIR	*dirp;
+    DIR       *dirp;  
+#else /* _WINDOWS */
+    struct _finddata_t dbuf;
+    char bufn[_MAX_PATH + 4];
+    long findrv;
+#endif /* !_WINDOWS */
     CertList *cert, *cl;
-    int  ret = 0;
+    int  ret = 0, nfiles = 0, nerr = 0;
 
+#ifndef _WINDOWS
     if((dirp = opendir(path)) != NULL){
-        while(!ret && (d=readdir(dirp)) != NULL){
-            if(srchrstr(d->d_name, ext)){
-    	    	build_path(buf, path, d->d_name, sizeof(buf));
+      while(!ret && (d=readdir(dirp)) != NULL){
+            fname = d->d_name;
+#else /* _WINDOWS */
+    snprintf(bufn, sizeof(bufn), "%s%s*.*", path, (path[strlen(path)-1] == '\\') ? "" : "\\");
+    bufn[sizeof(bufn)-1] = '\0';
+    if((findrv = _findfirst(bufn, &dbuf)) >= 0){
+      do{
+          fname = fname_to_utf8(dbuf.name);
+#endif /* ! _WINDOWS */
+            if(srchrstr(fname, ext)){
+              nfiles++;
+              build_path(buf, path, fname, sizeof(buf));
 
     	    	if(!X509_LOOKUP_load_file(lookup, buf, X509_FILETYPE_PEM)){
 		    q_status_message1(SM_ORDER, 3, 3, _("Error loading file %s"), buf);
-		    ret = -1;
+		    nerr++;
 		} else {
 		  if(cdata){
 		     BIO *in;
@@ -688,7 +727,7 @@ add_certs_in_dir(X509_LOOKUP *lookup, char *path, char *ext, CertList **cdata)
 
 		     cert = fs_get(sizeof(CertList));
 		     memset((void *)cert, 0, sizeof(CertList));
-		     cert->name = cpystr(d->d_name);
+		     cert->name = cpystr(fname);
 		     /* read buf into a bio and fill the CertData structure */
 		     if((in = BIO_new_file(buf, "r"))!=0){
 			if((x = PEM_read_bio_X509(in, NULL, NULL, NULL)) != NULL){
@@ -712,11 +751,17 @@ add_certs_in_dir(X509_LOOKUP *lookup, char *path, char *ext, CertList **cdata)
 		}
             }
 
-        }
-
-        closedir(dirp);
+#ifndef _WINDOWS
+      }
+      closedir(dirp);
+#else  /* _WINDOWS */
+      } while(_findnext(findrv, &dbuf) == 0);
+      _findclose(findrv);
+#endif /* ! _WINDOWS */
     }
 
+    /* if all certificates fail to load */
+    if(nerr > 0 && nerr == nfiles) ret = -1;
     return ret;
 }
 
@@ -741,7 +786,7 @@ get_ca_store(void)
 
     if(!(lookup=X509_STORE_add_lookup(store, X509_LOOKUP_file()))){
 	dprint((9, "X509_STORE_add_lookup() failed"));
-	X509_STORE_free(store);
+	free_x509_store(&store);
 	return NULL;
     }
     
@@ -749,21 +794,21 @@ get_ca_store(void)
        && ps_global->smime->cacontent){
 
 	if(!mem_add_extra_cacerts(ps_global->smime->cacontent, lookup)){
-	    X509_STORE_free(store);
+	    free_x509_store(&store);
 	    return NULL;
 	}
     }
     else if(ps_global->smime && ps_global->smime->catype == Directory
 	    && ps_global->smime->capath){
 	if(add_certs_in_dir(lookup, ps_global->smime->capath, ".crt", &ps_global->smime->cacertlist) < 0){
-	    X509_STORE_free(store);
+	    free_x509_store(&store);
 	    return NULL;
 	}
 	resort_certificates(&ps_global->smime->cacertlist, CACert);
     }
 
-    if(!(lookup=X509_STORE_add_lookup(store, X509_LOOKUP_hash_dir()))){
-	X509_STORE_free(store);
+    if(!(lookup = X509_STORE_add_lookup(store, X509_LOOKUP_hash_dir()))){
+	free_x509_store(&store);
 	return NULL;
     }
 
@@ -775,6 +820,14 @@ get_ca_store(void)
     return store;
 }
 
+void
+free_x509_store(X509_STORE **xstore)
+{
+  if(xstore == NULL || *xstore == NULL)
+     return;
+  X509_STORE_free(*xstore);
+  *xstore = NULL;
+}
 
 EVP_PKEY *
 load_key(PERSONAL_CERT *pc, char *pass, int flag)
@@ -824,7 +877,7 @@ load_key(PERSONAL_CERT *pc, char *pass, int flag)
 /*
  * This newer version is from Adrian Vogel. It looks for the email
  * address not only in the email address field, but also in an
- * X509v3 extension field, Subject Altenative Name.
+ * X509v3 extension field, Subject Alternative Name.
  */
 char **
 get_x509_subject_email(X509 *x)
@@ -1205,7 +1258,7 @@ get_cert_for(char *email, WhichCerts ctype, int tolower)
 	build_path(certfilename, PATHCERTDIR(ctype), emailaddr, sizeof(certfilename));
 	strncat(certfilename, EXTCERT(ctype), sizeof(certfilename)-1-strlen(certfilename));
 	certfilename[sizeof(certfilename)-1] = 0;
-	    
+
 	if((in = BIO_new_file(certfilename, "r"))!=0){
 
 	    cert = PEM_read_bio_X509(in, NULL, NULL, NULL);
@@ -1216,6 +1269,7 @@ get_cert_for(char *email, WhichCerts ctype, int tolower)
 
 	    BIO_free(in);
 	}
+
     }
 
     return cert;
@@ -1231,26 +1285,40 @@ get_cert_for(char *email, WhichCerts ctype, int tolower)
 int
 load_cert_for_key(char *pathdir, EVP_PKEY *pkey, char **certfile, X509 **pcert)
 {
+#ifndef _WINDOWS
    DIR *dirp;
    struct dirent *d;
+#else /* _WINDOWS */
+    struct _finddata_t dbuf;
+    char bufn[_MAX_PATH + 4];
+    long findrv;
+#endif /* ! _WINDOWS */
+   size_t ll;
    int rv = 0;
    BIO *in;
    X509 *x;
-   char buf[MAXPATH+1], pathcert[MAXPATH+1];
+   char buf[MAXPATH+1], pathcert[MAXPATH+1], *fname;
 
    if(pathdir == NULL || pkey == NULL)
     return 0;
 
    if(certfile) *certfile = NULL;
    if(pcert)    *pcert = NULL;
-           
+ 
+#ifndef _WINDOWS
    if((dirp = opendir(pathdir)) != NULL){
       while(rv == 0 && (d=readdir(dirp)) != NULL){
-        size_t ll;
-    
-	if((ll=strlen(d->d_name)) && ll > 4){
-	   if(!strcmp(d->d_name+ll-4, ".crt")){
-	     strncpy(buf, d->d_name, sizeof(buf));
+	fname = d->d_name;
+#else
+   snprintf(bufn, sizeof(bufn), "%s%s*.*", pathdir, (pathdir[strlen(pathdir)-1] == '\\') ? "" : "\\");
+   bufn[sizeof(bufn)-1] = '\0';   
+   if((findrv = _findfirst(bufn, &dbuf)) >= 0){
+      do{
+        fname = fname_to_utf8(dbuf.name);
+#endif /* ! _WINDOWS */
+	if((ll=strlen(fname)) && ll > 4){
+	   if(!strcmp(fname+ll-4, ".crt")){
+	     strncpy(buf, fname, sizeof(buf));
 	     buf[sizeof(buf)-1] = '\0';
 	     build_path(pathcert, pathdir, buf, sizeof(pathcert));
 	     if((in = BIO_new_file(pathcert, "r")) != NULL){
@@ -1267,8 +1335,13 @@ load_cert_for_key(char *pathdir, EVP_PKEY *pkey, char **certfile, X509 **pcert)
 	     }
 	   }
         }
+#ifndef _WINDOWS
       }
       closedir(dirp);
+#else /* _WINDOWS */
+      } while(_findnext(findrv, &dbuf) == 0);
+	  _findclose(findrv);
+#endif
    }
    return rv;
 }
