@@ -4,7 +4,7 @@ static char rcsid[] = "$Id: string.c 910 2008-01-14 22:28:38Z hubert@u.washingto
 
 /*
  * ========================================================================
- * Copyright 2013-2017 Eduardo Chappa
+ * Copyright 2013-2020 Eduardo Chappa
  * Copyright 2006-2008 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -520,7 +520,7 @@ srchstr(char *haystack, char *needle)
           ss -- The string to search for, the smaller string
 
    Search for last occurrence of ss in the is, and return a pointer
-   into the string is when it is found. The search is case indepedent.
+   into the string is when it is found. The search is case independent.
   ----*/
 
 char *	    
@@ -1093,7 +1093,7 @@ The following date formats are accepted:
   DD MM WKDAY YY MM HH:MM:SS ZZ
 
 All leading, intervening and trailing spaces tabs and commas are ignored.
-The prefered formats are the first or second ones.  If a field is unparsable
+The preferred formats are the first or second ones.  If a field is unparsable
 it's value is left as -1. 
 
   ----*/
@@ -1223,7 +1223,7 @@ parse_date(char *given_date, struct date *d)
         while(*p && (*p == '-' || *p == ',' || isspace((unsigned char)*p)))
           p++;
     } else {
-        /* Something wierd, skip it and try to resynch */
+        /* Something weird, skip it and try to resynch */
         while(*p && !isspace((unsigned char)*p) && *p != ',' && *p != '-')
           p++;
         while(*p && (isspace((unsigned char)*p) || *p == ',' || *p == '-'))
@@ -1930,7 +1930,7 @@ get_pair(char *string, char **label, char **value, int firstws, int strip_intern
 
 	*p = '\0';				/* tie off label */
 	fs_give((void **)&tmp);
-	if(*label == '\0')
+	if(*label == NULL)
 	  fs_give((void **)label);
     }
     else
@@ -2819,7 +2819,7 @@ copy_quoted_string_asis(char *src)
 
 /*
  * isxpair -- return true if the first two chars in string are
- *	      hexidecimal characters
+ *	      hexadecimal characters
  */
 int
 isxpair(char *s)
@@ -2839,11 +2839,23 @@ isxpair(char *s)
 STRLIST_S *
 new_strlist(char *name)
 {
-    STRLIST_S *sp = (STRLIST_S *) fs_get(sizeof(STRLIST_S));
-    memset(sp, 0, sizeof(STRLIST_S));
-    if(name)
-      sp->name = cpystr(name);
+  return new_strlist_auth(name, NULL, '\0');
+}
 
+STRLIST_S *
+new_strlist_auth(char *name, char *authtype, char sep)
+{
+    STRLIST_S *sp = (STRLIST_S *) fs_get(sizeof(STRLIST_S));
+    int len = authtype ? strlen(authtype) : 0;
+    int offset = authtype ? 1 : 0;
+
+    memset(sp, 0, sizeof(STRLIST_S));
+    if(name){
+      sp->name = fs_get(strlen(name) + len + offset + 1);
+      sprintf(sp->name, "%s%s%s", authtype ? authtype :  "",
+			authtype ? " " : "", name);
+      if(authtype != NULL) sp->name[len] = sep;
+    }
     return(sp);
 }
 
@@ -2917,8 +2929,8 @@ free_strlist(STRLIST_S **strp)
 void
 convert_decimal_to_roman (char *rn, size_t len, long n, char l)
 {
-  char symbols[7];
-  int amo[7];
+  char symbols[8];
+  int amo[8];
   int i, j, k;
 
   rn[0] = '\0';
@@ -2932,6 +2944,7 @@ convert_decimal_to_roman (char *rn, size_t len, long n, char l)
   symbols[4] = l + 'x' - 'i';
   symbols[5] = l + 'v' - 'i';
   symbols[6] = l;
+  symbols[7] = '\0';
   
   amo[0] = n/1000; n -= amo[0]*1000;
   amo[1] = n/500;  n -= amo[1]*500;
@@ -2940,6 +2953,7 @@ convert_decimal_to_roman (char *rn, size_t len, long n, char l)
   amo[4] = n/10;   n -= amo[4]*10;
   amo[5] = n/5;    n -= amo[5]*5;
   amo[6] = n;
+  amo[7] = 0;		/* make valgrind happy */
 
   for(i = 0, j = 0; i < len && j < strlen(symbols); j++){
      if(amo[j] < 4){
