@@ -2,7 +2,7 @@
  * $Id: string.h 769 2007-10-24 00:15:40Z hubert@u.washington.edu $
  *
  * ========================================================================
- * Copyright 2013-2017 Eduardo Chappa
+ * Copyright 2013-2020 Eduardo Chappa
  * Copyright 2006-2007 University of Washington
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -85,7 +85,7 @@ struct date {
 #define BUILDER_FOOTER_MANGLED		0x4
 
 
-/* exported protoypes */
+/* exported prototypes */
 char	   *rplstr(char *, size_t, int, char *);
 void	    sqzspaces(char *);
 void	    sqznewlines(char *);
@@ -144,6 +144,7 @@ char       *add_escapes(char *, char *, int, char *, char *);
 char       *copy_quoted_string_asis(char *);
 int	    isxpair(char *);
 STRLIST_S  *new_strlist(char *);
+STRLIST_S  *new_strlist_auth(char *, char *, char);
 STRLIST_S  *copy_strlist(STRLIST_S *);
 void	    combine_strlists(STRLIST_S **, STRLIST_S *);
 void	    free_strlist(STRLIST_S **);
